SystemOrganization addCategory: #ScriptLoader14!

Object subclass: #Loader
	instanceVariableNames: ''
	classVariableNames: 'PackagesBeforeLastLoad'
	poolDictionaries: ''
	category: 'ScriptLoader14'!

!Loader commentStamp: 'LaurentLaffont 3/4/2011 22:44' prior: 0!
I'm an abstract class which collect some infos about package and system (versions, dirty).
#currentChangedPackages instance method and #currentMajorVersionNumber class are missing and provided by my wellknown subclass ScriptLoader (see ScriptLoader comment).


Stef: This is a class that was extracted from scriptLoader because I want to slowly get in place a loader infrastructure based on Metacello.!

!Loader class methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:22'!
packageToBeTestedFolderName

	^ 'packages-to-be-tested'! !

!Loader class methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:22'!
waitingCacheFolder
	^ (FileDirectory default directoryNamed: self packageToBeTestedFolderName)
		assureExistence;
		yourself

	! !

!Loader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2010 17:41'!
allCurrentVersions
	"self new allCurrentVersions"
	
	| copies names |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	names := copies collect:
		[:ea |  ea ancestry ancestorString ].
	^ names reject: #isEmpty! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:51'!
currentChangedPackages
	"self new currentChangedPackages" 
	
	^  self currentPackages select: [:each |
		each needsSaving or: [
			(PackagesBeforeLastLoad includes: each ancestry ancestorString) not ] ]! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumber

	^ self class currentMajorVersionNumber ! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumberWithoutDot
	"self new currentMajorVersionNumberWithoutDot"
	^ self class currentMajorVersionNumber asString copyWithout: $.! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:42'!
currentVersionsToBeSaved
	"self new currentVersionsToBeSaved"
	
	^ self allCurrentVersions reject: [ :each |
		self packagesNotToSavePatternNames
			anySatisfy: [ :p | p match: each ] ]! !

!Loader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 9/10/2010 17:51'!
diffPackages
	"return a list of packages that are new. They can be dirty or not."
	"self new diffPackages"
	 
	| diff |
	diff := Set new.
	self currentVersionsToBeSaved do: [:each |
		(PackagesBeforeLastLoad includes: each) ifFalse: [diff add: each]].
	^ diff
	! !

!Loader methodsFor: 'initialize' stamp: 'StephaneDucasse 9/10/2010 17:49'!
initialize
	super initialize.
	PackagesBeforeLastLoad ifNil: [ PackagesBeforeLastLoad := Set new ]! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
markPackagesBeforeNewCodeIsLoaded
	"Use this method to keep a log of all the packages that were loaded before loading new code. This will help the system to perform a diff and know after what to publish."
	
	"self new markPackagesBeforeNewCodeIsLoaded"
	
	PackagesBeforeLastLoad := self currentVersionsToBeSaved! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:40'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'Metacello*'
			'SLICE*'
			'Slice*'
			'slice*'
		).! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
resetPackagesBeforeLastLoad
	PackagesBeforeLastLoad := Set new! !

Loader subclass: #ScriptLoader
	instanceVariableNames: 'repository inboxRepository repository39 repositorySqueakTrunk repository310 repositoryTaskForces repositoryMC repositoryTreated'
	classVariableNames: 'CheckImageInSyncWithUpdate CurrentMajorVersionNumber CurrentScriptVersionNumber CurrentUpdateVersionNumber CurrentlyIntegratingChanges LogStream Repository'
	poolDictionaries: 'TextConstants'
	category: 'ScriptLoader14'!

!ScriptLoader commentStamp: 'StephaneDucasse 5/26/2010 20:49' prior: 0!
Pharo Process Description


---
Here is the pharo process.

General points
-----------------------
An enhancement
	- should be added to the bug tracker
	- announced to the mailing-list
	- asked for feedback 
	- results should be added to the BT entry

Fixed tag means ready for integration
Closed tag means integrated

A bug detected
	- discuss via the mailing-list
	- should be added to the bug tracker
	- fix are considered as enh (see point above)

When a fix is fixed it should be either post as cs to the BT entry or in the PharoInbox
as a Slice (a slice is an emtpy package that has as requirement other package composing the fix).

We have three projects:
	Pharo
	PharoInbox
	PharoTreatedInbox

A fix goes either from inbox to treatedInbox or to Pharo.
If a fix does not work it is moved to the TreatedInbox.
If a fix works it is integrated as follow - it will be moved from the Inbox to the TreatedInbox
and integrated and published in the Pharo project

To help browsing multiple repositories:

ScriptLoader new addExtraRepositories


+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Now the integration works in 4 main steps which can be steered by the following expression
ScriptLoader releaseMenu
or via the menu that can be shown/hidden using 
	ScriptLoader showIntegrationMenu
	ScriptLoader hideIntegrationMenu


1.) Start up a recent and clean image
	ScriptLoader new prepareNewUpdate
	
	This step will 
		- load the latest updates
		- load the latest ScriptLoader package from the Pharo repository.
		Indeed when we work on improving the ScriptLoader it may not be published in the update stream. 
		New versions can be available on the server but not part of the latest updates.
		Therefore the process always loads the latest version of scriptloader from the pharo repository.
		This point is important because when an integration failed, you have to check and optionally 
		remove the scriptloader package from the pharo repository.
		
		- check that the update.list (which contains the cs to load the packages) is in sync
		with the image current version. You have to download the latest version using a script like this one.
		Pay attention to update it so that it reflects the right version (ie 1.0, 1.1, 1.2...)
		     scp -p LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/updates.list .
		- snapshot the package version to detect dirty or changed but non dirty packages.

2.) Apply changes

	ScriptLoader new doneApplyingChanges
	
	This step will 
		- create an update method with can trigger the load of the packages and some pre/post actions
		- create a script method with describes all the package versions and it used by the update methods
		- save all the packages that are different (except some filtered packages)	
		into a local folder named package-to-be-tested.
		ScriptLoader, SLICE*.... and a couple of other packages are not considered to be included in the script method
			(check method packagesNotToSavePatternNames)
		

3.) Verify changes
	==> in a ***new*** image (in the current folder) execute:
	ScriptLoader new verifyNewUpdate

	This step will 
		- load in any order (so may break) the package previously saved
		in the packages to be tested.
		- this step is important because you may get simple changes with unexpected side effects and that 
		may break the load.
		

4.) If there are problems go to 2.) to fix them, else:
	ScriptLoader new publishChanges

	This step will
		- generate a new cs file whose purpose is to load the given version of the scriptloader and trigger the 
		correct update method.
		- add the name of the cs file to the end of the updates.list file local to the disc
		- copy all the package from the local directory to the Pharo
		
	After the updates.list and the cs file should be manually uploaded to the ftp (see below) 
	   scp "$1" LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/
	

5) in case of problems.
Think that if you pass the step 4 you may have a scriptLoader version that got published and that is reloaded 
during the first step.



CurrentMajorVersionNumber should contains a string '1.0', '1.1'....
This string will determine on which folder on the server the updates.list should be loaded.
	i.e., updates/pharo1.0, updates/pharo1.1 ....

--- Not to forget ---
To change the release stream
add a new method for each releaseStream
	ScriptLoader toPharoOne
	ScriptLoader toPharoOneDotOne
!

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 9/10/2010 17:28'!
checkImageInSyncWithUpdate
	"most of the time you want to make sure that your image is in sync with the latest item of the update.list
	but in some cases you do not to get forced to have this behavior."
	
	^ CheckImageInSyncWithUpdate ifNil: [CheckImageInSyncWithUpdate := true]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 6/12/2010 08:47'!
checkImageInSyncWithUpdate: aBoolean

	CheckImageInSyncWithUpdate := aBoolean! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:15'!
currentMajorVersionNumber

	^ CurrentMajorVersionNumber ! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:12'!
currentMajorVersionNumber: aNumber

	CurrentMajorVersionNumber := aNumber! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:06'!
currentlyIntegratingChanges

	CurrentlyIntegratingChanges isNil ifTrue: [self hideIntegrationMenu].
	^ CurrentlyIntegratingChanges! !

!ScriptLoader class methodsFor: 'private' stamp: 'adrian_lienhard 3/16/2009 21:32'!
defaultMCWaitingFolder
	"self defaultMCWaitingFolder" 
	
	^ MCDirectoryRepository new directory: self waitingCacheFolder! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			(self new)
				installGofer;
				gofer ]! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
hideIntegrationMenu

	CurrentlyIntegratingChanges := false.! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'StephaneDucasse 9/10/2010 17:24'!
initialize
	self flag: #shouldRemoveNumber.
	CurrentMajorVersionNumber :=  1.2! !

!ScriptLoader class methodsFor: 'source' stamp: 'PavelKrivanek 9/30/2010 11:11'!
latestSource: packageName location: location

  | contents versionName zip |
  
  versionName := location, '/', (self latestVersionOf: packageName location: location).
  contents := HTTPSocket httpGet: versionName args: nil user: '' passwd: ''.
    
  zip := ZipArchive new.
  zip readFrom: contents.
  (zip memberNamed: 'snapshot/source.st') contents.
  ^  (zip memberNamed: 'snapshot/source.st') contents.! !

!ScriptLoader class methodsFor: 'source' stamp: 'PavelKrivanek 9/30/2010 11:11'!
latestVersionOf: packageName location: location

  | repository sortMczs fileToLoad | 
  
  repository := MCHttpRepository location: location user: '' password: ''.
  sortMczs := [:a :b |
    [(a findBetweenSubStrs: #($.)) allButLast last asInteger > (b  
      findBetweenSubStrs: #($.)) allButLast last asInteger]
    on: Error do: [:ex | false]].
  
  fileToLoad := (repository readableFileNames asSortedCollection: sortMczs) detect: 
    [:file | file beginsWith: (packageName, '-')].
  
  ^ fileToLoad! !

!ScriptLoader class methodsFor: 'private' stamp: 'al 11/1/2008 20:03'!
loadLatestPackage: aString from: aPath
	| repository |
	
	repository := MCHttpRepository
		location: aPath
		user:  ''
		password: ''.
	self loadLatestPackage: aString fromRepository: repository! !

!ScriptLoader class methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
loadLatestPackage: aString fromRepository: aRepository
	| versionsBlock versions tries |
	
	versionsBlock := [ (aRepository allVersionNames select: [ :each |
		each beginsWith: aString ])
		asSortedCollection: [ :a :b |
			(a copyAfterLast: $.) asNumber <= (b copyAfterLast: $.) asNumber]].
	versions := versionsBlock value.
	tries := 0.
	[ versions isEmpty and: [ tries < 3 ] ] whileTrue: [
		versions := versionsBlock value.
		tries := tries + 1 ].
	versions isEmpty ifTrue: [ self error: 'problems when accessing squeaksource' ].
	
	aRepository versionReaderForFileNamed: (versions last , '.mcz') do: [:reader | | version |
		version := reader version.
		version load.
		version workingCopy repositoryGroup addRepository: aRepository]! !

!ScriptLoader class methodsFor: 'private' stamp: 'AlexandreBergel 10/23/2008 15:31'!
loadLatestPackage: aString fromSqueaksource: aDirectoryName
	" self loadLatestPackage: 'ScriptLoader' fromSqueaksource: 'Pharo' "

	self loadLatestPackage: aString from: 'http://www.squeaksource.com/', aDirectoryName
	! !

!ScriptLoader class methodsFor: 'menu' stamp: 'FernandoOlivero 4/12/2011 10:14'!
menuCommandOn: aBuilder 
	<worldMenu> 
	
	(aBuilder item: #'Integrator Menu')
		order: 1.5;
		precondition: [self currentlyIntegratingChanges];
		parent: #System;
		icon: self theme smallAuthoringToolsIcon;
		action: [ScriptLoader releaseMenu]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 11/9/2010 18:39'!
releaseMenu
	"self releaseMenu"
	|symbol|
	symbol := UIManager default
		chooseFrom: #('1- Prepare new update'
		                        '2- Save new image for testing (optional)'
						'3- Freeze changes: packages will be saved (required)'
						'4- Verify new update (open the mother image in the same folder) (optional)'
						'5- Publish changes')
		values: #(prepareNewUpdate saveImageForRunningTests doneApplyingChanges verifyNewUpdate publishChanges).
	symbol ifNotNil: [ScriptLoader new perform: symbol]! !

!ScriptLoader class methodsFor: 'public' stamp: 'adrian-lienhard 6/6/2009 11:46'!
resetLogStream
	LogStream := nil! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
showIntegrationMenu

	CurrentlyIntegratingChanges := true.! !

!ScriptLoader class methodsFor: 'menu' stamp: 'FernandoOlivero 4/12/2011 10:14'!
theme
	^ UITheme current ! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:14'!
toPharoOne

	self currentMajorVersionNumber: 1.0! !

!ScriptLoader class methodsFor: 'public' stamp: 'MarcusDenker 6/16/2011 17:29'!
toPharoOneDotFour

	self currentMajorVersionNumber: 1.4! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:14'!
toPharoOneDotOne

	self currentMajorVersionNumber: 1.1! !

!ScriptLoader class methodsFor: 'public' stamp: 'MarcusDenker 1/18/2011 16:56'!
toPharoOneDotThree

	self currentMajorVersionNumber: 1.3! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 5/14/2010 22:21'!
toPharoOneDotTwo

	self currentMajorVersionNumber: 1.2! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 2/25/2010 18:22'!
CSForLastUpdate: aString
	"ScriptLoader new CSForLastUpdate: 'cleanUpMethods'"
	
	| str updateNumber filename|
	updateNumber := self getLatestUpdateNumber.
	filename := updateNumber asString, '-Pha-', aString, '.cs'.
	FileDirectory default 
		forceNewFileNamed:  filename
		do: [ :stream | 
					self 
						generateCS: self latestScriptLoaderPackageIdentificationString
						fromUpdate: updateNumber on: stream].
	^ filename! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 1/31/2010 22:31'!
CSForLastUpdateAndPatchUpdatesList: aString
	"ScriptLoader new CSForLastUpdateAndPatchUpdatesList: 'cleanUpMethods'"
	| filename |
	filename := self CSForLastUpdate: aString.
	self updateUpdatesList: aString.
	^ filename ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addExtraRepositories
	
	"self new addExtraRepositories"
	
	self addRepository39ToAllPackages.
	self addRepository310ToAllPackages.
	self addRepositoryTaskForcesToAllPackages.
	self addRepositorySqueakTrunkToAllPackages.
	self addRepositoryMCToAllPackages.
	self addRepositoryTreatedToAllPackages.! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 11/13/2010 21:51'!
addHomeRepositoryToAllPackages
	"self new addHomeRepositoryToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository;
			 addRepository: self inboxRepository;
			addRepository: self repositoryTreated ].
		
	MCRepositoryGroup default
			 addRepository: self repository;
			 addRepository: self inboxRepository;
			 addRepository: self repositoryTreated.
	
		
	
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 17:40'!
addHomeRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 10/18/2009 16:11'!
addPackage: aString
	"to be tested" 
	
	| workingCopy |
	PackageInfo registerPackageName: aString.
	workingCopy := MCWorkingCopy forPackage: (MCPackage new name: aString)! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/13/2009 15:48'!
addRepository310ToAllPackages
	"self new addRepository310ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository310
			].
	
	! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/6/2009 17:38'!
addRepository39ToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepository39ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository39
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/14/2009 10:31'!
addRepositoryMCToAllPackages
	
	"self new addRepositoryMCToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryMC
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2009 20:47'!
addRepositorySqueakTrunkToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepositorySqueakTrunkToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositorySqueakTrunk
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/13/2009 15:59'!
addRepositoryTaskForcesToAllPackages
	"self new addRepositoryTaskForcesToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTaskForces
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 10/31/2005 18:01'!
addRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addRepositoryTreatedToAllPackages
	"self new addRepositoryTreatedToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTreated
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentDirtyPackages
	"ScriptLoader new allCurrentDirtyPackages"
	"return all the current dirty packages even the ones that we do not want to save"

	
	^  self allCurrentPackages select: [:each | each needsSaving].

	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentPackages
	"ScriptLoader new allCurrentPackages" 
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:26'!
announceOnMailingList
	"
	self new announceOnMailingList"
	|title|
	title := '[update ', self currentMajorVersionNumber asString , '] #', self currentUpdateVersionNumber asString.
UIManager default
	edit: title, String cr, self currentUpdateVersionNumber asString, '
-----

', self commentForCurrentUpdate
	label: title.! !

!ScriptLoader methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
buildConfigurationMapFor: packageNames

	| configurationMap |
	configurationMap := MCConfiguration new.
	configurationMap repositories
		add: self repository;
		add: self inboxRepository.

	packageNames do: [:packageName | | version depArray |
		version := self loadVersionFromFileNamed: packageName.
		depArray := { version package name. version info name. version info id asString. }.
		configurationMap dependencies add: (MCConfiguration dependencyFromArray: depArray)].
	^configurationMap! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 1/31/2011 22:23'!
checkImageIsUptodate

	| stream last number |
	self class checkImageInSyncWithUpdate 
		ifFalse: [^ true].	
	stream := FileDirectory default oldFileNamed: self updatesListFileName.
	stream contents linesDo: [ :each | last := each ].
	stream close.
	last isNil 
		ifTrue: [^ false]. "in case the file is empty"
	 (last copyUpTo: $-) isAllDigits
		ifFalse: [^ true].  			"for cases where we have #Pharo1.1rc1 starting the line"
	number := (last copyUpTo: $-) asNumber.
	^ number = self getLatestUpdateNumber.
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 11/13/2010 22:31'!
cleanRepositories
	"self new cleanRepositories"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllRepositories.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 6/17/2011 10:00'!
cleanUpForProduction
	"self new cleanUpForProduction"
	
	| oldDicts newDicts |
	
	"trim MC ancestory information"
	MCVersionInfo allInstances do: [ :each | each instVarNamed: 'ancestors' put: nil ].	

	"delete logo"	
	LogoImageMorph default: nil.

	"delete ScriptLoader log"
	ScriptLoader resetLogStream.

	Smalltalk globals at: #SUnitUnloader ifPresent:[ :unloader | unloader new unloadAll  ].
	(MCPackage named: 'HelpSystem-Core') unload.
	(MCPackage named: 'Deprecated12') unload.
	(MCPackage named: 'Deprecated13') unload.
	
	"shrink method dictionaries."
	Smalltalk garbageCollect.
	oldDicts := MethodDictionary allInstances.
	newDicts := Array new: oldDicts size.
	oldDicts withIndexDo: [ :d :index | newDicts at: index put: d rehashWithoutBecome ].
	oldDicts elementsExchangeIdentityWith: newDicts.
	oldDicts := newDicts := nil.
	
	self removeDejaVuFonts.
	(MCPackage named: 'Graphics-Resources') unload.
	
	(MCPackage named: 'HostMenus') unload.
	
	self cleanUpForRelease.
	(MCPackage named: self theScriptLoaderPackageName) unload.
	ChangeSet removeChangeSetsNamedSuchThat: [ :each | true ].
	ChangeSet resetCurrentToNewUnnamedChangeSet.
	RecentMessageList cleanUp.
	Smalltalk garbageCollect
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 4/22/2011 10:38'!
cleanUpForRelease
	"self new cleanUpForRelease"

	Author fullName: 'Mr.Cleaner'.
	self cleanUpPackageOrganizer.
	self cleanUpMethods.
	Smalltalk cleanUp: true except: #() confirming: false.
	ImageMorph classPool at: #DefaultForm put: (Form extent: 1 @ 1 depth: 1).
	Smalltalk organization removeEmptyCategories.
	Smalltalk globals
		at: #TTFontDescription
		ifPresent: [ :c | 
			c
				clearDefault;
				clearDescriptions ].
	ExternalDropHandler resetRegisteredHandlers.
	FreeTypeFontProvider current initialize.
	SystemNavigation default
		allObjectsDo: [ :each | 
			(each respondsTo: #releaseCachedState)
				ifTrue: [ each releaseCachedState ] ].
	3 timesRepeat: [ 
		Smalltalk garbageCollect.
		Symbol compactSymbolTable ].
	HashedCollection rehashAll.
	
	"Remove empty categories, which are not in MC packages, because MC does
	not do this (this script does not make packages dirty)"
	Smalltalk organization removeEmptyCategories.
	Smalltalk
		allClassesAndTraitsDo: [ :class |
			[ :each |
				each
					removeEmptyCategories;
					sortCategories ]
						value: class organization;
						value: class class organization ].
	PackageOrganizer default packages
		do: [ :each | each methods ifEmpty: [ PackageOrganizer default unregisterPackage: each ] ]
		displayingProgress: 'Cleaning Packages'.
	Smalltalk organization sortCategories.
	ChangeSet removeChangeSetsNamedSuchThat: [ :each | true ].
	ChangeSet resetCurrentToNewUnnamedChangeSet.
	Smalltalk garbageCollect.
	Author reset! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 6/5/2010 11:12'!
cleanUpMethods
	"Make sure that all methods in use are restarted"
	"ScriptLoader new cleanUpMethods"

	WeakArray restartFinalizationProcess.
	MethodChangeRecord allInstancesDo: [:x | x noteNewMethod: nil].
	WorldState allInstancesDo: [ :ws | ws convertAlarms; convertStepList; resetWorldMenu].
	WorldState allInstancesDo: [ :ws | ws instVarNamed: 'menuBuilder' put: nil ].
	ExternalDropHandler initialize.
	ScrollBar initializeImagesCache.
	GradientFillStyle initPixelRampCache.
	ProcessBrowser initialize.
	Smalltalk garbageCollect.
	Delay startTimerEventLoop! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 12/5/2009 11:19'!
cleanUpPackageOrganizer

	PackageOrganizer default packages
		do: [ :each | 
			each methods isEmpty
				ifTrue: [ PackageOrganizer default unregisterPackage: each ] ]
		displayingProgress: 'Cleaning Packages'! !

!ScriptLoader methodsFor: 'public' stamp: 'MarcusDenker 8/12/2011 18:38'!
commentForCurrentUpdate
 ^ '- FS update'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 14:36'!
compileNewUpdateMethod
	"Use me to create a new update method with the next update number"
	"self new compileNewUpdateMethod"
	

	self class compile: 
		(self newGenerateNewUpdateMethod)
		classified: 'pharo - updates'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 13:26'!
compileScriptMethodWithCurrentPackages: aNumber 
	"ScriptLoader new compileScriptMethodWithCurrentPackages: 9999"
	
	self class compile: 
		(self newGenerateScriptTemplateWithCurrentPackages: aNumber)
		classified: 'pharo - scripts'! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
copyPackagesFromWaitingFolderToHomeRepository
	"self defaultMCWaitingFolder allFileNames"
	"self new copyPackageFromWaitingFolderToHomeRepository"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		self repository storeVersion: version]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'al 11/1/2008 19:49'!
currentPackages
	"self new currentPackages" 
	
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies reject: [:each |
		self packagesNotToSavePatternNames
			anySatisfy: [:p | p match: each package name]].
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:08'!
currentScriptVersionNumber
	^ CurrentScriptVersionNumber! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 9/8/2009 14:41'!
currentUpdateVersionNumber
	^ CurrentUpdateVersionNumber ifNil: [SystemVersion current highestUpdate]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 5/29/2006 20:52'!
currentVersions
	"ScriptLoader new currentVersions"
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies collect:
		[:ea |  ea ancestry ancestorString ]! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:46'!
deletePackage: aString

	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	MCWorkingCopy registry removeKey: toRemove package.! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 5/3/2010 22:54'!
doneApplyingChanges
	| comment commentQuoted st |
	SmalltalkImage current saveSession.
		"now you can reopen prior to publishing to fix :)"
	self saveAsNewImageWithCurrentReleaseNameToPublish.
	
	comment := UIManager default
		multiLineRequest: 'Comment for this update.'
		centerAt: Sensor cursorPoint
		initialAnswer: self commentForCurrentUpdate
		answerHeight: 200.
	comment ifNil: [^ self].
	
	commentQuoted := comment copyReplaceAll: (String with: $') with: (String with: $' with: $').
	st := String new writeStream.
	st nextPutAll: 'commentForCurrentUpdate'; cr.
	st nextPutAll: ' ^ '.
	st nextPut: $'.
	st nextPutAll: commentQuoted.
	st nextPut: $'.
	self class
		compile: (st contents)
		classified: 'public'.

	self class waitingCacheFolder deleteLocalFiles.
	self saveChangedPackagesIntoWaitingFolder.
	self generateScriptAndUpdateMethodForNewVersion.
	self saveLatestScriptLoaderToWaitingFolder.
	
	self inform: 'Update prepared and ready to be verified.'! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 8/15/2010 12:33'!
fixObsoleteReferences
	"self new fixObsoleteReferences"
	CompiledMethod allInstances
		do: [ :method | 
			| obsoleteBindings |
			obsoleteBindings := method literals
				select: [ :literal | literal isVariableBinding 
									and: [ literal value isBehavior and: [ literal value isObsolete ]] ].
			obsoleteBindings
				do: [ :binding | 
					| realClass obsName realName |
					obsName := binding value name.
					Transcript
						show: obsName;
						cr.
					realName := obsName copyReplaceAll: 'AnObsolete' with: ''.
					realClass := Smalltalk globals at: realName asSymbol ifAbsent: [ UndefinedObject ].
					binding key: binding key value: realClass ] ].
	Behavior flushObsoleteSubclasses.
	Smalltalk
		garbageCollect;
		garbageCollect.
	SystemNavigation default obsoleteBehaviors size > 0
		ifTrue: [ SystemNavigation default obsoleteBehaviors inspect ]! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 3/14/2010 12:44'!
flushCaches

	MCFileBasedRepository flushAllCaches.
	MCDefinition clearInstances.
	Smalltalk garbageCollect.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'MarcusDenker 6/16/2011 18:19'!
generateCS: packageInfo fromUpdate: updateNumber on: st
	
	st nextPutAll:
'"Postscript:
Leave the line above, and replace the rest of this comment by a useful one.
Executable statements should follow this comment, and should
be separated by periods, with no exclamation points (!!!!).
Be sure to put any further comments in double-quotes, like this one."

|repository|
repository := MCHttpRepository
                location: ''http://www.squeaksource.com/Pharo14/''
                user: ''''
                password: ''''.
(repository loadVersionFromFileNamed:' .
	st nextPut: $' ; nextPutAll: packageInfo, '.mcz'') load.'; cr.
	st nextPutAll: 'ScriptLoader new update', (updateNumber) asString; nextPutAll: '.' ; cr.
	st nextPutAll: '!!'.
	^ st contents
! !

!ScriptLoader methodsFor: 'utils' stamp: 'stephane.ducasse 7/4/2009 12:27'!
generateCompleteFixList
	"generateCompleteFixList"
	| stream |
	stream := (FileStream newFileNamed: 'changes-log.txt').
	[ stream nextPutAll: ScriptLoader new logStream contents ] ensure: [ stream close ]! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 8/30/2009 14:48'!
generateNewUpdateMethod
	"ScriptLoader new generateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		centerAt: Sensor cursorPoint
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, '.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					centerAt: Sensor cursorPoint
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'adrianLienhard 11/1/2008 23:05'!
generateScriptAndUpdateMethodForNewVersion
	"Use me to generate the script and update method"
	"self new generateScriptAndUpdateMethodForNewVersion"
	
	self compileScriptMethodWithCurrentPackages: self currentScriptVersionNumber.
	self compileNewUpdateMethod.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 14:41'!
generateScriptTemplateWithAllCurrentPackages
	"ScriptLoader new generateScriptTemplateWithAllCurrentPackages"
	
	| str |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'scriptXXX' ; cr ; cr ; tab.
	str nextPutAll: '| names|'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	self currentVersionsToBeSaved do: 
		[:each |
			str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 18:07'!
generateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '| names |'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'al 11/1/2008 18:15'!
getLatestScriptNumber
	"self new getLatestScriptNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'script*' match: each ].
	upfroms := upfroms collect: [:each | (each asString allButFirst: 6)].
	upfroms := upfroms reject: [:each | '*Log*' match: each ].
	upfroms := upfroms reject: [:each | '*XXX*' match: each ].
	upfroms := upfroms collect: [:each | each asNumber].
	^ upfroms asSortedCollection last
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 10/17/2009 12:33'!
getLatestUpdateNumber
	"self new getLatestUpdateNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'update*' match: each ].
	upfroms := upfroms collect: [:each | [(each asString last: 5) asNumber] on: Error do: [0]].
	^ upfroms asSortedCollection last! !

!ScriptLoader methodsFor: 'accessing' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			self
				installGofer;
				gofer ]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'CarloTeixeira 8/11/2010 00:37'!
inboxRepository
	^ inboxRepository ifNil: [inboxRepository :=  MCHttpRepository inboxRepository]
	! !

!ScriptLoader methodsFor: 'utils' stamp: 'lr 7/10/2009 18:07'!
installGofer
	"self new installGofer"
	
	self class loadLatestPackage: 'Gofer' from: 'http://source.lukas-renggli.ch/flair'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 14:46'!
installRepository: aString for: packageName

	(MCWorkingCopy allManagers select: [:each | each package name = packageName])
		first repositoryGroup
		addRepository: (MCHttpRepository new location: aString ; user: '' ; password: '')
		! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'alain.plantec 2/6/2009 15:49'!
installVersionInfo
	"self new installVersionInfo"

	| highestUpdate newVersion |
	highestUpdate := SystemVersion current highestUpdate.
	(self confirm: 'Reset highest update (' , highestUpdate printString , ')?')
		ifTrue: [SystemVersion current highestUpdate: 0].

	newVersion := UIManager default request: 'New version designation:' translated initialAnswer: '3.9' , highestUpdate printString. 
	SystemVersion newVersion: newVersion.
	
! !

!ScriptLoader methodsFor: 'utils' stamp: 'lr 3/14/2010 21:13'!
installingInstaller
	"self new installingInstaller"

	| mc files fileToLoad version |
	mc := Smalltalk globals
		at: #MCHttpRepository
		ifPresent: [ :repoClass | repoClass location: 'www.squeaksource.com/Installer' user: 'squeak' password: 'squeak' ].
	files := mc readableFileNames
		asSortedCollection: [ :a :b | 
			[ (a findBetweenSubStrs: #($.)) allButLast last asInteger > (b findBetweenSubStrs: #($.)) allButLast last asInteger ]
				on: Error
				do: [ :ex | false ] ].
	fileToLoad := files detect: [ :aFile | aFile beginsWith: 'Installer-Core' ] ifNone: [ nil ].
	version := mc versionFromFileNamed: fileToLoad.
	version workingCopy repositoryGroup addRepository: mc.
	mc creationTemplate: mc asCreationTemplate.
	version load.
	^ Smalltalk globals at: #Installer! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 8/14/2008 16:03'!
latestScriptLoaderPackageIdentificationString
	"ScriptLoader new latestScriptLoaderPackageIdentificationString"
	
	^  self allCurrentVersions detect: [:each | 'ScriptLoader*' match: each ]
	! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'Jb 10/23/2010 12:14'!
launchUpdate

	UpdateStreamer new updateFromServer! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'MarcusDenker 6/17/2011 09:48'!
loadLatestScriptloader
	"self new loadLatestScriptloader"
	
	self class 
		loadLatestPackage: 'ScriptLoader', self currentMajorVersionNumberWithoutDot 
		fromSqueaksource: 'Pharo14' 
	

! !

!ScriptLoader methodsFor: 'private' stamp: 'SvenVanCaekenberghe 7/8/2011 15:09'!
loadLatestUpdateList
	"fetch the latest version of the update.list on the server"
	
	| result listToUse lastUpdate |
	(result := ZnClient get: UpdateStreamer new updateFolderURL, self updatesListFileName) isSuccess
		ifFalse: [ self error: 'Cannot access update server' ].
	listToUse := result contents.			
	listToUse linesDo: [:each | lastUpdate := each].
	(lastUpdate beginsWith: self getLatestUpdateNumber asString)
		 ifTrue: ["Write this file as our current updates.list"
			FileDirectory default
				forceNewFileNamed: self updatesListFileName
				do: [:stream | stream nextPutAll: listToUse]]
		ifFalse: [ 
			self inform: 'Image update version did not match automatically fetched  update.list!!  
			Proceed after downloading using the script ./getUpdatesList instead' ].
	! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'nice 1/5/2010 15:59'!
loadOneAfterTheOther: aCollection merge: aBoolean
	
	(self newerVersionsIn: aCollection)
		do: [:fn | | loader |
			loader := aBoolean
				ifTrue: [ MCVersionMerger new ]
				ifFalse: [ MCVersionLoader new].
			loader addVersion: (self repository loadVersionFromFileNamed: fn).
			aBoolean
				ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
							request merger conflicts isEmpty
								ifTrue: [request resume: true]
								ifFalse: [request pass]]]
				ifFalse: [loader load]]
  	  	displayingProgress: 'Loading versions...'.
	

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'adrian_lienhard 2/21/2009 13:40'!
loadOneAfterTheOther: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadOneAfterTheOther: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			self loadOneAfterTheOther: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
loadPackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		version load]! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'michael.rueger 1/13/2009 15:26'!
loadTogether: aCollection merge: aBoolean
	| loader |
	loader := aBoolean
		ifTrue: [ MCVersionMerger new ]
		ifFalse: [ MCVersionLoader new].
	(self newerVersionsIn: aCollection)
		do: [:fn | loader addVersion: (self loadVersionFromFileNamed: fn)]
  	  	displayingProgress: 'Adding versions...'.
	aBoolean
		ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
					request merger conflicts isEmpty
						ifTrue: [request resume: true]
						ifFalse: [request pass]]]
		ifFalse: [loader hasVersions ifTrue: [loader load]]

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 5/10/2008 12:41'!
loadTogether: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadTogether: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			 self loadTogether: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'private' stamp: 'michael.rueger 1/13/2009 15:25'!
loadVersionFromFileNamed: fn
	| version |
	version := self repository loadVersionFromFileNamed: fn.
	^version
		ifNil: [self inboxRepository loadVersionFromFileNamed: fn]! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 4/4/2008 14:47'!
log: aString

	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/15/2008 18:30'!
logContents

	^ self logStream contents! !

!ScriptLoader methodsFor: 'log' stamp: 'adrian_lienhard 3/16/2009 21:30'!
logStream
	^ LogStream ifNil: [
		LogStream := ReadWriteStream on: (String new: 1000)]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
mergePackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles
		do: [ :name | | version |
			version := self class defaultMCWaitingFolder  versionFromFileNamed: name.
			version merge.
			]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'AdrianLienhard 6/5/2010 11:08'!
metacelloRepository
	^ (MCHttpRepository 
		location: 'http://www.squeaksource.com/MetacelloRepository'
		user: ''
		password: '')
	! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:35'!
newGenerateNewUpdateMethod
	"ScriptLoader new newGenerateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		centerAt: Sensor cursorPoint
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self loadTogether: '.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, ' merge: false.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					centerAt: Sensor cursorPoint
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:25'!
newGenerateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	"this version change the script to only "
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '^ '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr'.
	^ str contents! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 10/13/2005 21:44'!
newerVersionsIn: aCollection
	^aCollection reject: [:each |
		MCWorkingCopy allManagers anySatisfy: [:workingcopy |
			workingcopy ancestry ancestorString , '.mcz' = each]].! !

!ScriptLoader methodsFor: 'utils' stamp: 'sd 2/4/2008 16:09'!
openWindow: contents label: aLabel

	StringHolder new 
		contents: contents ;
		openLabel: aLabel! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 7/17/2010 13:35'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'AST*'
			'*Refactoring*'
			'Metacello*'
			'SLICE*'
			'Slice*'
			'slice*'
			'*OB-*'
			'OmniBrowser*'
		).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 7/7/2010 23:23'!
prepareNewUpdate
	self launchUpdate.
	self loadLatestScriptloader.
	self markPackagesBeforeNewCodeIsLoaded.
	self checkImageIsUptodate ifFalse: [self loadLatestUpdateList].
	self checkImageIsUptodate ifFalse: [
		^ self inform: 'Your update.list and your image are not in sync!! Please use a fresh image and download the latest update.list and start over. May be you are doing a rollback and you should remove the bogus ScriptLoader version from the Pharo repository' ].
	self setUpdateAndScriptVersionNumbers.
	self saveAsNewImageWithCurrentReleaseName.
	self inform: 'The new version number is ' , self currentUpdateVersionNumber asString , '. Ready to apply changes now.', String cr, 'You are now running in image ', (FileDirectory baseNameFor: (FileDirectory default localNameFor: Smalltalk imageName)).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 1/31/2011 22:17'!
publishChanges
	| username password changescriptname changesetFilename str strings|
	(FileStream isAFileNamed: 'PharoPass.txt') 
		ifTrue: [ str := FileStream fileNamed:  'PharoPass.txt'. 
				strings := str contents substrings.
				username := strings first.
				password := strings second] 
		ifFalse: [ username := UIManager default request: 'Pharo repository login'.
			     password := UIManager default requestPassword: 'Pharo repository password'.].

	self setToRepositoriesPassword: password to: username.
	
	changescriptname := UIManager default request: 'Changeset name (no space)' initialAnswer: 'WhatAsChanged'.
	changesetFilename := self CSForLastUpdateAndPatchUpdatesList: changescriptname.
	self copyPackagesFromWaitingFolderToHomeRepository.
	self announceOnMailingList.
	self inform: 'All packages have been uploaded to the Pharo repository.
Remaining manual steps:
1) ./upFilesXX ',changesetFilename,'
2) ./upFilesXX updatesXX.list
3) Announce new update on mailing list'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 11/13/2010 22:30'!
removeAllHTTPRepositories: aColl
	"self new removeAllRepositories: 
			#('http://source.squeakfoundation.org/inbox/'
			 'http://source.squeakfoundation.org/39a/'
			 'http://source.squeakfoundation.org/Balloon/'
			 'http://source.squeakfoundation.org/Compression/'
			 'http://source.squeakfoundation.org/Graphics/'
			  'http://source.wiresong.ca/mc/')"
 
	
	MCWorkingCopy allManagers do: [:each | 
		aColl
			do: [:location | 
					each  repositoryGroup removeHTTPRepositoryLocationNamed: location]].
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 3/11/2010 20:22'!
removeAllRepositories
	"self new removeAllRepositories"
	
	MCWorkingCopy allManagers do: [:each |  each  repositoryGroup initialize].
	MCRepositoryGroup default initialize.
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'BenjaminVanRyseghem 11/28/2010 19:02'!
removeDejaVuFonts
	"Note, you need to close all windows to make the Deja Vu fonts being GCed"

	StandardFonts setDefaultFonts: #(
		(defaultFont: 'Accuny' 10)
		(codeFont: 'Accuny' 10)
		(listFont: 'Accuny' 10)
		(menuFont: 'Accuny' 10)
		(windowTitleFont: 'Accuny' 10)
		(balloonFont: 'Accuny' 10)
		(buttonFont: 'Accuny' 10)).
	TextSharedInformation removeKey: 'Bitmap DejaVu Sans'! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:06'!
removeScriptMethods
	"self new removeScriptMethods"
	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - scripts') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:04'!
removeUpdateMethods

	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - updates') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'accessing' stamp: 'MarcusDenker 6/16/2011 18:16'!
repository
	^ repository ifNil: [
		repository := MCHttpRepository new
			location:  'http://www.squeaksource.com/Pharo14';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/13/2009 15:48'!
repository310
	^ repository310 ifNil: [
		repository310 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/310';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repository39
	^ repository39 ifNil: [
		repository39 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/39a';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'adrian_lienhard 3/16/2009 21:42'!
repository: aRepository
	repository := aRepository! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/14/2009 10:32'!
repositoryMC
	^ repositoryMC ifNil: [
		repositoryMC := MCHttpRepository new
			location:  'http://source.wiresong.ca/mc';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repositorySqueakTrunk
	^ repositorySqueakTrunk ifNil: [
		repositorySqueakTrunk := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/trunk';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/13/2009 15:59'!
repositoryTaskForces
	^ repositoryTaskForces ifNil: [
		repositoryTaskForces := MCHttpRepository new
			location:  'http://www.squeaksource.com/PharoTaskForces';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/26/2009 07:47'!
repositoryTreated
	^ repositoryTreated ifNil: [
		repositoryTreated := MCHttpRepository new
			location:  'http://www.squeaksource.com/PharoTreatedInbox';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/8/2010 22:30'!
saveAsImageAsTestImage
	"Now you can run tests and see and go back to the previous image
	and do that go and back.... then after you can decide to freeze"

	|name|
	name := FileDirectory default
				nextNameFor: (self shortImageName, '-imageForTestsFor')
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'private' stamp: 'DamienCassou 9/8/2009 14:42'!
saveAsNewImageWithCurrentReleaseName
	|name|
	name := FileDirectory default
				nextNameFor: ('releasePharo-',  self currentUpdateVersionNumber asString)
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/8/2010 22:31'!
saveAsNewImageWithCurrentReleaseNameToPublish
	"If the reload failed and you do not want to lose time reload all the cs and packages... you can now restart from the image saved now"
	
	|name|
	name := FileDirectory default
				nextNameFor: (self shortImageName, '-releasePharoToPublish')
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'al 11/1/2008 18:33'!
saveChangedPackagesIntoWaitingFolder
	self currentChangedPackages do: [:each |
		self
			saveInToReloadCachePackage: each
			with: self commentForCurrentUpdate]! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 11/9/2010 18:38'!
saveImageForRunningTests

	| comment commentQuoted st resuming |
	resuming := false.
	SmalltalkImage current saveSession
		ifFalse: [ resuming := true].
	resuming ifTrue: [
		self saveAsImageAsTestImage.
	
		self inform: 'Now you can use this image named ''Test'' to run the tests and come back to fix problems in the \ previous one and eventually freeze it by selecting the next step, in either one.' withCRs]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'adrianLienhard 11/2/2008 00:31'!
saveInToReloadCachePackage: aWorkingCopy with: aMessageString
	self
		savePackage: aWorkingCopy
		in: self class defaultMCWaitingFolder
		with: aMessageString! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/28/2010 20:06'!
saveLatestScriptLoaderToHome
	"self new saveLatestScriptLoaderToHome"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader*' match: each  package name].
	self repository storeVersion: r first newVersion.! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/12/2010 13:31'!
saveLatestScriptLoaderToWaitingFolder
	"self new saveLatestScriptLoaderToWaitingFolder"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader', self currentMajorVersionNumberWithoutDot, '*' match: each  package name].
	self
		saveInToReloadCachePackage: r first
		with: self commentForCurrentUpdate! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 10/20/2009 11:28'!
savePackage: aWorkingCopy in: aRepository with: aMessageString
	" | sc |
	  sc := self new.
	  sc savePackage: (self new workingCopyFromPackageName: 'ScriptLoader11') 
		in: MCCacheRepository default
		with: 'this is test to automate dirty package saving in cache'"

	aRepository storeVersion: (aWorkingCopy 
		newVersionWithName: aWorkingCopy uniqueVersionName
		message: aMessageString)! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/17/2011 10:00'!
script267

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.46.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-StephaneDucasse.58.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-StephaneDucasse.552.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.899.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.521.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.104.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.945.mcz
MorphicTests-MarcusDenker.36.mcz
Multilingual-Display-MarcusDenker.20.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.56.mcz
Polymorph-Widgets-MarcusDenker.461.mcz
RecentSubmissions-StephaneDucasse.94.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40142.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.525.mcz
System-Text-MarcusDenker.171.mcz
System-Tools-MarcusDenker.54.mcz
Tests-MarcusDenker.301.mcz
ToolBuilder-Kernel-MarcusDenker.70.mcz
ToolBuilder-Morphic-StephaneDucasse.129.mcz
Tools-MarcusDenker.626.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-StephaneDucasse.166.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/20/2011 10:44'!
script268

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.46.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.59.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-StephaneDucasse.552.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.899.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.521.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.104.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.945.mcz
MorphicTests-MarcusDenker.36.mcz
Multilingual-Display-MarcusDenker.20.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.56.mcz
Polymorph-Widgets-MarcusDenker.461.mcz
RecentSubmissions-MarcusDenker.95.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40142.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.525.mcz
System-Text-MarcusDenker.171.mcz
System-Tools-MarcusDenker.54.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.626.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-StephaneDucasse.166.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/21/2011 09:35'!
script269

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.46.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.59.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-StephaneDucasse.552.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.899.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.521.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.104.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.946.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.20.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.56.mcz
Polymorph-Widgets-MarcusDenker.462.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40142.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.526.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.54.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.626.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-StephaneDucasse.166.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/21/2011 16:15'!
script270

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.46.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.59.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-StephaneDucasse.552.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.899.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.521.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.104.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.946.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.20.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.56.mcz
Polymorph-Widgets-MarcusDenker.462.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40142.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.526.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.54.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.626.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/21/2011 16:56'!
script271

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-StephaneDucasse.552.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.899.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.521.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.104.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.946.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.20.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.56.mcz
Polymorph-Widgets-MarcusDenker.462.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40142.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.526.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.54.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.626.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/23/2011 21:11'!
script272

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.553.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.899.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.522.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.104.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.946.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.20.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.56.mcz
Polymorph-Widgets-MarcusDenker.462.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.526.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.54.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.626.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/24/2011 09:52'!
script273

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.553.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.899.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.522.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.104.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.947.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.56.mcz
Polymorph-Widgets-MarcusDenker.462.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.527.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.54.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.626.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/24/2011 14:28'!
script274

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.553.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.899.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.523.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.104.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.947.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.57.mcz
Polymorph-Widgets-MarcusDenker.462.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.527.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.54.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.626.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/24/2011 17:11'!
script275

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.553.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.899.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.524.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.947.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.58.mcz
Polymorph-Widgets-MarcusDenker.462.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.527.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.54.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.626.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/24/2011 17:41'!
script276

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.553.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.899.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.525.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.947.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.462.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.527.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.54.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.626.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 6/24/2011 18:26'!
script277

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.553.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.900.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.525.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.947.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.462.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.527.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.54.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.626.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/26/2011 11:42'!
script278

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.553.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.900.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.947.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.40.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.463.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.527.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.55.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.627.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/26/2011 17:05'!
script279

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.900.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.947.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.41.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.464.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.528.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.55.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/26/2011 18:30'!
script280

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.900.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.947.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.41.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.464.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.528.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.55.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/27/2011 12:44'!
script281! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/27/2011 17:50'!
script282

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.60.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.901.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.948.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.42.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.465.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.528.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.55.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/28/2011 07:49'!
script283

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.7.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.901.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.949.mcz
MorphicTests-MarcusDenker.37.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.42.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.466.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.528.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.55.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/28/2011 09:30'!
script284

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.901.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.950.mcz
MorphicTests-MarcusDenker.38.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.42.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.467.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.528.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.55.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/28/2011 15:30'!
script285

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.951.mcz
MorphicTests-MarcusDenker.38.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-LaurentLaffont.63.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.42.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.468.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.528.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.55.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 6/30/2011 08:40'!
script286

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.951.mcz
MorphicTests-MarcusDenker.38.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.42.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.468.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.55.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.44.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/1/2011 08:21'!
script287

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.951.mcz
MorphicTests-MarcusDenker.38.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.43.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.468.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/2/2011 12:35'!
script288

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.951.mcz
MorphicTests-MarcusDenker.38.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-MarcusDenker.43.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.469.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/2/2011 16:59'!
script289

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.60.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.24.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.951.mcz
MorphicTests-MarcusDenker.38.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.469.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/3/2011 10:15'!
script290

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.952.mcz
MorphicTests-MarcusDenker.38.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.469.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/5/2011 12:58'!
script291

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.952.mcz
MorphicTests-MarcusDenker.38.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.469.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.628.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/6/2011 09:26'!
script292

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.952.mcz
MorphicTests-MarcusDenker.38.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.469.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/7/2011 17:03'!
script293

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.953.mcz
MorphicTests-MarcusDenker.38.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.470.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/8/2011 12:19'!
script294

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.93.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.953.mcz
MorphicTests-MarcusDenker.38.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.470.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/8/2011 12:48'!
script295

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.94.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.954.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/8/2011 13:22'!
script296

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.902.mcz
KernelTests-MarcusDenker.329.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.954.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/8/2011 14:21'!
script297

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.903.mcz
KernelTests-StephaneDucasse.331.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.954.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/8/2011 16:16'!
script298

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-MarcusDenker.47.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.903.mcz
KernelTests-StephaneDucasse.331.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.954.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-MarcusDenker.16.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.65.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.110.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/8/2011 17:02'!
script299

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.49.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.903.mcz
KernelTests-StephaneDucasse.331.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.956.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.112.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-MarcusDenker.172.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.85.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/14/2011 12:20'!
script300

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.49.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.903.mcz
KernelTests-StephaneDucasse.331.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.956.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.112.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/14/2011 16:28'!
script301

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.49.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.908.mcz
KernelTests-StephaneDucasse.334.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.956.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.112.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/14/2011 17:14'!
script302

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.49.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.909.mcz
KernelTests-StephaneDucasse.335.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-MarcusDenker.526.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.105.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.956.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.112.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/14/2011 20:16'!
script303

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-IgorStasenko.39.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.49.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.909.mcz
KernelTests-StephaneDucasse.335.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.527.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.956.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.112.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/14/2011 21:31'!
script304

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.49.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.909.mcz
KernelTests-StephaneDucasse.335.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.527.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.957.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.112.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/15/2011 22:31'!
script305

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-MarcusDenker.61.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.525.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-MarcusDenker.290.mcz
CompilerTests-StephaneDucasse.90.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.49.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-MarcusDenker.10.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-MarcusDenker.61.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.11.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.913.mcz
KernelTests-StephaneDucasse.338.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.527.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.960.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.112.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-MarcusDenker.56.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.137.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.233.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-MarcusDenker.172.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.301.mcz
Tools-MarcusDenker.629.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/15/2011 22:51'!
script306

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.92.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.961.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.529.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/16/2011 22:19'!
script307

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.94.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.961.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.531.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/16/2011 23:02'!
script308

	^ 'Announcements-Core-MarcusDenker.25.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.94.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-MarcusDenker.ducasse.212.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.961.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.2.mcz
Ring-Tests-Core-Containers-StephaneDucasse.2.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.531.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2011 15:27'!
script309

	^ 'Announcements-Core-StephaneDucasse.27.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.94.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.214.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.961.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.2.mcz
Ring-Tests-Core-Containers-StephaneDucasse.2.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.531.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2011 15:59'!
script310

	^ 'Announcements-Core-StephaneDucasse.27.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.94.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.214.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.961.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.3.mcz
Ring-Core-Kernel-StephaneDucasse.2.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.531.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2011 16:33'!
script311

	^ 'Announcements-Core-StephaneDucasse.27.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.94.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.214.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.961.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.4.mcz
Ring-Core-Kernel-StephaneDucasse.2.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.532.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2011 16:58'!
script312

	^ 'Announcements-Core-StephaneDucasse.27.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.94.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.961.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.4.mcz
Ring-Core-Kernel-StephaneDucasse.2.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.532.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/18/2011 17:47'!
script313

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.94.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.961.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.4.mcz
Ring-Core-Kernel-StephaneDucasse.2.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.1.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.532.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/19/2011 10:44'!
script314

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.94.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.961.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.8.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.2.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.532.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/19/2011 13:39'!
script315

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.94.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.961.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.9.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.533.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/22/2011 15:32'!
script316

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.94.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.961.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.471.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.13.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.534.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/22/2011 15:53'!
script317

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.94.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.40.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.914.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.962.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.472.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.13.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.534.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/22/2011 16:17'!
script318

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.52.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.916.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.963.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.472.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.13.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.534.mcz
System-Text-StephaneDucasse.174.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/22/2011 16:34'!
script319

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.917.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.964.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.51.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.472.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.13.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.534.mcz
System-Text-StephaneDucasse.175.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.631.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/22/2011 18:16'!
script320

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.917.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.964.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.472.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.13.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.534.mcz
System-Text-StephaneDucasse.175.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.635.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/22/2011 18:39'!
script321

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.917.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.965.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.472.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.13.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.534.mcz
System-Text-StephaneDucasse.175.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.635.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'IgorStasenko 7/22/2011 19:25'!
script322

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.917.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-IgorStasenko.966.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-IgorStasenko.473.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.13.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.534.mcz
System-Text-StephaneDucasse.175.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.635.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/22/2011 22:32'!
script323

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.917.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.967.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-IgorStasenko.473.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.13.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.534.mcz
System-Text-StephaneDucasse.176.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.636.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/22/2011 23:16'!
script324

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.918.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.968.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-IgorStasenko.473.mcz
RecentSubmissions-MarcusDenker.96.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.13.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.534.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.303.mcz
Tools-StephaneDucasse.637.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/26/2011 15:34'!
script325

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.918.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.968.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-IgorStasenko.473.mcz
RecentSubmissions-StephaneDucasse.97.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.14.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40143.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.535.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.304.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'IgorStasenko 7/27/2011 10:36'!
script326

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.918.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.968.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-IgorStasenko.473.mcz
RecentSubmissions-StephaneDucasse.97.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.14.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-IgorStasenko.40144.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.535.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.304.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/28/2011 13:23'!
script327

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.918.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.968.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-IgorStasenko.473.mcz
RecentSubmissions-StephaneDucasse.97.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.14.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.1.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.1.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.535.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.304.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 7/28/2011 14:46'!
script328

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.918.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.968.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.475.mcz
RecentSubmissions-StephaneDucasse.97.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.14.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.1.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.1.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.536.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.304.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/28/2011 23:13'!
script329

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.918.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.969.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.475.mcz
RecentSubmissions-StephaneDucasse.97.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.14.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-StephaneDucasse.40145.mcz
SUnit-Core-MarcusDenker.1.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.1.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.536.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.304.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/28/2011 23:50'!
script330

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.918.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.969.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.475.mcz
RecentSubmissions-StephaneDucasse.97.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.14.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-StephaneDucasse.40145.mcz
SUnit-Core-MarcusDenker.1.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.1.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.114.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.536.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.304.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 7/29/2011 15:49'!
script331

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-StephaneDucasse.918.mcz
KernelTests-StephaneDucasse.339.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.106.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.969.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.475.mcz
RecentSubmissions-StephaneDucasse.97.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.14.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.1.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.1.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.115.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.536.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.304.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/1/2011 11:05'!
script332

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.1.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.340.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.107.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.969.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.475.mcz
RecentSubmissions-StephaneDucasse.97.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.14.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.115.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.536.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.304.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/1/2011 11:42'!
script333

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.1.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.340.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.107.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.969.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.475.mcz
RecentSubmissions-StephaneDucasse.97.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.14.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.115.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.536.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.304.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/1/2011 22:59'!
script334

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.340.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.107.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.969.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.11.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.475.mcz
RecentSubmissions-StephaneDucasse.98.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.15.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.116.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.537.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.305.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/2/2011 10:39'!
script335

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-StephaneDucasse.93.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.340.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.107.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.969.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.475.mcz
RecentSubmissions-StephaneDucasse.98.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.15.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.116.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.537.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.305.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/2/2011 19:38'!
script336

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.107.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.969.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.476.mcz
RecentSubmissions-StephaneDucasse.98.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.15.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.116.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.538.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.305.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/2/2011 22:58'!
script337

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.107.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.970.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.476.mcz
RecentSubmissions-StephaneDucasse.99.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.15.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.116.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.538.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.305.mcz
Tools-StephaneDucasse.638.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/3/2011 10:21'!
script338

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.2.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.31.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.107.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.970.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.476.mcz
RecentSubmissions-StephaneDucasse.99.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.15.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.538.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.305.mcz
Tools-MarcusDenker.640.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/4/2011 08:41'!
script339

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-StephaneDucasse.96.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-StephaneDucasse.528.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.2.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.108.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.970.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.476.mcz
RecentSubmissions-StephaneDucasse.99.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.15.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.538.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.305.mcz
Tools-MarcusDenker.640.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/4/2011 12:30'!
script340

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.98.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.2.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.108.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.970.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.476.mcz
RecentSubmissions-StephaneDucasse.99.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.15.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.538.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.305.mcz
Tools-MarcusDenker.640.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/4/2011 12:34'!
script341

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.95.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.2.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.108.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.970.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-MarcusDenker.476.mcz
RecentSubmissions-StephaneDucasse.99.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.15.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.538.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.305.mcz
Tools-MarcusDenker.640.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/4/2011 15:33'!
script342

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.97.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.2.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.110.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.970.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-StephaneDucasse.99.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.15.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.539.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.305.mcz
Tools-MarcusDenker.640.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'IgorStasenko 8/8/2011 15:02'!
script343

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.2.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.530.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.110.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.970.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.71.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-StephaneDucasse.99.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.15.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-MarcusDenker.1.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.539.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.305.mcz
Tools-MarcusDenker.640.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/9/2011 18:09'!
script344

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.2.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.135.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.531.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.111.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.970.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.73.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-StephaneDucasse.100.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.16.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.2.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.540.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.306.mcz
Tools-StephaneDucasse.641.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/10/2011 23:35'!
script345

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.2.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.135.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.531.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.112.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.971.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.73.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-StephaneDucasse.100.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.5.mcz
Ring-Core-Kernel-StephaneDucasse.16.mcz
Ring-Tests-Containers-StephaneDucasse.1.mcz
Ring-Tests-Kernel-StephaneDucasse.3.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.2.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.540.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.306.mcz
Tools-StephaneDucasse.642.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 8/12/2011 12:00'!
script346

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.2.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.135.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.531.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.112.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.971.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.73.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-StephaneDucasse.100.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.7.mcz
Ring-Core-Kernel-StephaneDucasse.22.mcz
Ring-Tests-Containers-StephaneDucasse.3.mcz
Ring-Tests-Kernel-StephaneDucasse.10.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.2.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.540.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.306.mcz
Tools-StephaneDucasse.642.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/12/2011 14:23'!
script347

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.2.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
FS-AnsiStreams-MarcusDenker.2.mcz
FS-Core-MarcusDenker.7.mcz
FS-Disk-MarcusDenker.2.mcz
FS-FileStream-MarcusDenker.2.mcz
FS-Memory-MarcusDenker.2.mcz
FS-Tests-AnsiStreams-MarcusDenker.2.mcz
FS-Tests-Core-MarcusDenker.6.mcz
FS-Tests-Disk-MarcusDenker.2.mcz
FS-Tests-Memory-MarcusDenker.2.mcz
FS-Zip-MarcusDenker.2.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.135.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.531.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.112.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.971.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.73.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-StephaneDucasse.100.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.7.mcz
Ring-Core-Kernel-StephaneDucasse.22.mcz
Ring-Tests-Containers-StephaneDucasse.3.mcz
Ring-Tests-Kernel-StephaneDucasse.10.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.2.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.540.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.306.mcz
Tools-StephaneDucasse.642.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/12/2011 15:04'!
script348

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arithmetic-MarcusDenker.5.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.3.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
FS-AnsiStreams-MarcusDenker.2.mcz
FS-Core-MarcusDenker.7.mcz
FS-Disk-MarcusDenker.2.mcz
FS-FileStream-MarcusDenker.2.mcz
FS-Memory-MarcusDenker.2.mcz
FS-Tests-AnsiStreams-MarcusDenker.2.mcz
FS-Tests-Core-MarcusDenker.6.mcz
FS-Tests-Disk-MarcusDenker.2.mcz
FS-Tests-Memory-MarcusDenker.2.mcz
FS-Zip-MarcusDenker.2.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.135.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.919.mcz
KernelTests-MarcusDenker.342.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.531.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.112.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.971.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.73.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-StephaneDucasse.100.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.7.mcz
Ring-Core-Kernel-StephaneDucasse.22.mcz
Ring-Tests-Containers-StephaneDucasse.3.mcz
Ring-Tests-Kernel-StephaneDucasse.10.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.2.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.540.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-StephaneDucasse.306.mcz
Tools-MarcusDenker.643.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/12/2011 15:31'!
script349

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-StephaneDucasse.139.mcz
Collections-Arithmetic-MarcusDenker.5.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.3.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
FS-AnsiStreams-MarcusDenker.2.mcz
FS-Core-MarcusDenker.7.mcz
FS-Disk-MarcusDenker.2.mcz
FS-FileStream-MarcusDenker.2.mcz
FS-Memory-MarcusDenker.2.mcz
FS-Tests-AnsiStreams-MarcusDenker.2.mcz
FS-Tests-Core-MarcusDenker.6.mcz
FS-Tests-Disk-MarcusDenker.2.mcz
FS-Tests-Memory-MarcusDenker.2.mcz
FS-Zip-MarcusDenker.2.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.135.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.920.mcz
KernelTests-MarcusDenker.343.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.531.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.112.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.971.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.73.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-StephaneDucasse.100.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.7.mcz
Ring-Core-Kernel-StephaneDucasse.22.mcz
Ring-Tests-Containers-StephaneDucasse.3.mcz
Ring-Tests-Kernel-MarcusDenker.11.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.2.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.541.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.307.mcz
Tools-MarcusDenker.643.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/12/2011 16:20'!
script350

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-MarcusDenker.141.mcz
Collections-Arithmetic-MarcusDenker.5.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.3.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
FS-AnsiStreams-MarcusDenker.2.mcz
FS-Core-MarcusDenker.7.mcz
FS-Disk-MarcusDenker.2.mcz
FS-FileStream-MarcusDenker.2.mcz
FS-Memory-MarcusDenker.2.mcz
FS-Tests-AnsiStreams-MarcusDenker.2.mcz
FS-Tests-Core-MarcusDenker.6.mcz
FS-Tests-Disk-MarcusDenker.2.mcz
FS-Tests-Memory-MarcusDenker.2.mcz
FS-Zip-MarcusDenker.2.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.135.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.920.mcz
KernelTests-MarcusDenker.343.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.531.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.112.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.971.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.73.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-StephaneDucasse.100.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.7.mcz
Ring-Core-Kernel-StephaneDucasse.22.mcz
Ring-Tests-Containers-StephaneDucasse.3.mcz
Ring-Tests-Kernel-MarcusDenker.11.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.2.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-MarcusDenker.19.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.542.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.56.mcz
Tests-MarcusDenker.307.mcz
Tools-MarcusDenker.643.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/12/2011 16:49'!
script351

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-MarcusDenker.141.mcz
Collections-Arithmetic-MarcusDenker.5.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.3.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
FS-AnsiStreams-MarcusDenker.2.mcz
FS-Core-MarcusDenker.7.mcz
FS-Disk-MarcusDenker.2.mcz
FS-FileStream-MarcusDenker.2.mcz
FS-Memory-MarcusDenker.2.mcz
FS-Tests-AnsiStreams-MarcusDenker.2.mcz
FS-Tests-Core-MarcusDenker.6.mcz
FS-Tests-Disk-MarcusDenker.2.mcz
FS-Tests-Memory-MarcusDenker.2.mcz
FS-Zip-MarcusDenker.2.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.135.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.920.mcz
KernelTests-MarcusDenker.343.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.531.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.113.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.971.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.73.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-StephaneDucasse.100.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.7.mcz
Ring-Core-Kernel-StephaneDucasse.22.mcz
Ring-Tests-Containers-StephaneDucasse.3.mcz
Ring-Tests-Kernel-MarcusDenker.11.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.2.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-MarcusDenker.19.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.542.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.57.mcz
Tests-MarcusDenker.307.mcz
Tools-MarcusDenker.643.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/12/2011 17:25'!
script352

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-MarcusDenker.141.mcz
Collections-Arithmetic-MarcusDenker.5.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.3.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
FS-AnsiStreams-MarcusDenker.2.mcz
FS-Core-MarcusDenker.7.mcz
FS-Disk-MarcusDenker.2.mcz
FS-FileStream-MarcusDenker.2.mcz
FS-Memory-MarcusDenker.2.mcz
FS-Tests-AnsiStreams-MarcusDenker.2.mcz
FS-Tests-Core-MarcusDenker.6.mcz
FS-Tests-Disk-MarcusDenker.2.mcz
FS-Tests-Memory-MarcusDenker.2.mcz
FS-Zip-MarcusDenker.2.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.135.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.920.mcz
KernelTests-MarcusDenker.343.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.531.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.113.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.971.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.73.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-StephaneDucasse.100.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.7.mcz
Ring-Core-Kernel-StephaneDucasse.22.mcz
Ring-Tests-Containers-StephaneDucasse.3.mcz
Ring-Tests-Kernel-MarcusDenker.11.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.2.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
Shout-MarcusDenker.104.mcz
ShoutTests-MarcusDenker.14.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-MarcusDenker.19.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-StephaneDucasse.139.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.542.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.57.mcz
Tests-MarcusDenker.307.mcz
Tools-MarcusDenker.643.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/12/2011 18:24'!
script353

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-MarcusDenker.141.mcz
Collections-Arithmetic-MarcusDenker.5.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.3.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
FS-AnsiStreams-MarcusDenker.2.mcz
FS-Core-MarcusDenker.7.mcz
FS-Disk-MarcusDenker.2.mcz
FS-FileStream-MarcusDenker.2.mcz
FS-Memory-MarcusDenker.2.mcz
FS-Tests-AnsiStreams-MarcusDenker.2.mcz
FS-Tests-Core-MarcusDenker.6.mcz
FS-Tests-Disk-MarcusDenker.2.mcz
FS-Tests-Memory-MarcusDenker.2.mcz
FS-Zip-MarcusDenker.2.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.135.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.920.mcz
KernelTests-MarcusDenker.343.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.531.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.113.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.971.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.73.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-MarcusDenker.101.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.7.mcz
Ring-Core-Kernel-StephaneDucasse.22.mcz
Ring-Tests-Containers-StephaneDucasse.3.mcz
Ring-Tests-Kernel-MarcusDenker.11.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.2.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
Shout-MarcusDenker.104.mcz
ShoutTests-MarcusDenker.14.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-MarcusDenker.19.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.140.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.543.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.57.mcz
Tests-MarcusDenker.308.mcz
Tools-MarcusDenker.643.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 8/12/2011 18:38'!
script354

	^ 'Announcements-Core-StephaneDucasse.28.mcz
Announcements-Help-MarcusDenker.4.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-StephaneDucasse.9.mcz
Balloon-MarcusDenker.79.mcz
Collections-Abstract-MarcusDenker.141.mcz
Collections-Arithmetic-MarcusDenker.5.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-MarcusDenker.5.mcz
Collections-Native-MarcusDenker.5.mcz
Collections-Sequenceable-MarcusDenker.99.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-IgorStasenko.98.mcz
Collections-Strings-StephaneDucasse.184.mcz
Collections-Support-StephaneDucasse.42.mcz
Collections-Text-StephaneDucasse.64.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.120.mcz
Collections-Weak-IgorStasenko.59.mcz
CollectionsTests-MarcusDenker.530.mcz
Compatibility-MarcusDenker.5.mcz
Compiler-StephaneDucasse.293.mcz
CompilerTests-MarcusDenker.94.mcz
Compression-LaurentLaffont.86.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated13-StephaneDucasse.53.mcz
Deprecated14-MarcusDenker.3.mcz
DialogItemsChooser-MarcusDenker.15.mcz
EmergencyEvaluator-StephaneDucasse.13.mcz
FS-AnsiStreams-MarcusDenker.5.mcz
FS-Core-MarcusDenker.12.mcz
FS-Disk-MarcusDenker.3.mcz
FS-Memory-MarcusDenker.4.mcz
FS-Tests-MarcusDenker.2.mcz
FS-Tests-AnsiStreams-MarcusDenker.4.mcz
FS-Tests-Core-MarcusDenker.9.mcz
FS-Tests-Disk-MarcusDenker.3.mcz
FS-Tests-Memory-MarcusDenker.4.mcz
FS-Zip-MarcusDenker.3.mcz
Files-StephaneDucasse.ducasse.215.mcz
Finder-StephaneDucasse.64.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.554.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-StephaneDucasse.135.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.61.mcz
Graphics-External-StephaneDucasse.8.mcz
Graphics-Files-MarcusDenker.25.mcz
Graphics-Fonts-MarcusDenker.33.mcz
Graphics-Primitives-MarcusDenker.63.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.13.mcz
Graphics-Tests-StephaneDucasse.14.mcz
Graphics-Text-StephaneDucasse.17.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.82.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-LaurentLaffont.68.mcz
Kernel-MarcusDenker.920.mcz
KernelTests-MarcusDenker.343.mcz
MenuRegistration-StephaneDucasse.35.mcz
Monticello-StephaneDucasse.531.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.113.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.971.mcz
MorphicTests-StephaneDucasse.39.mcz
Multilingual-Display-MarcusDenker.21.mcz
Multilingual-Encodings-StephaneDucasse.18.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.14.mcz
Multilingual-Scanning-LaurentLaffont.27.mcz
Multilingual-Tests-MarcusDenker.12.mcz
Multilingual-TextConversion-StephaneDucasse.23.mcz
Network-Kernel-MarcusDenker.64.mcz
Network-MIME-LaurentLaffont.39.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.67.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-LaurentLaffont.32.mcz
Network-UUID-StephaneDucasse.18.mcz
Network-Url-MarcusDenker.51.mcz
NetworkTests-StephaneDucasse.53.mcz
PackageInfo-StephaneDucasse.73.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-Tools-Diff-StephaneDucasse.59.mcz
Polymorph-Widgets-StephaneDucasse.477.mcz
RecentSubmissions-MarcusDenker.101.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
Ring-Core-Containers-StephaneDucasse.7.mcz
Ring-Core-Kernel-StephaneDucasse.22.mcz
Ring-Tests-Containers-StephaneDucasse.3.mcz
Ring-Tests-Kernel-MarcusDenker.11.mcz
SUnit-Core-MarcusDenker.2.mcz
SUnit-Help-MarcusDenker.1.mcz
SUnit-Tests-MarcusDenker.2.mcz
SUnit-UI-StephaneDucasse.2.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-MarcusDenker.9.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.30.mcz
Settings-System-MarcusDenker.19.mcz
Settings-Tools-MarcusDenker.36.mcz
Shout-MarcusDenker.104.mcz
ShoutTests-MarcusDenker.14.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.37.mcz
System-BreakPoints-StephaneDucasse.2.mcz
System-Change Notification-MarcusDenker.19.mcz
System-Changes-MarcusDenker.117.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.7.mcz
System-Download-MarcusDenker.65.mcz
System-FilePackage-StephaneDucasse.58.mcz
System-FileRegistry-MarcusDenker.14.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.18.mcz
System-History-MarcusDenker.5.mcz
System-Installers-MarcusDenker.13.mcz
System-Localization-StephaneDucasse.60.mcz
System-Object Events-StephaneDucasse.11.mcz
System-Object Storage-MarcusDenker.140.mcz
System-Platforms-StephaneDucasse.16.mcz
System-Serial Port-StephaneDucasse.19.mcz
System-Settings-StephaneDucasse.235.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.543.mcz
System-Text-StephaneDucasse.177.mcz
System-Tools-MarcusDenker.57.mcz
Tests-MarcusDenker.308.mcz
Tools-MarcusDenker.643.mcz
ToolsTest-MarcusDenker.denker.18.mcz
Traits-StephaneDucasse.395.mcz
TrueType-StephaneDucasse.29.mcz
UI-Basic-MarcusDenker.8.mcz
UIManager-MarcusDenker.45.mcz
Zinc-HTTP-StephaneDucasse.175.mcz
Zinc-Patch-HTTPSocket-StephaneDucasse.2.mcz
Zinc-Tests-StephaneDucasse.88.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/13/2010 22:30'!
setToRepositoriesPassword: aPassword to: aUser
	"self new setToRepositoriesPassword: 'sd' to: 'zork'"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllHTTPRepositories: {self repository locationWithTrailingSlash . self inboxRepository locationWithTrailingSlash}. 
	self repository password: aPassword.
	self repository user: aUser.
	self inboxRepository password: aPassword.
	self inboxRepository user: aUser.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:07'!
setUpdateAndScriptVersionNumbers
	CurrentUpdateVersionNumber := self getLatestUpdateNumber + 1.
	CurrentScriptVersionNumber := self getLatestScriptNumber + 1.! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 11/8/2010 22:09'!
shortImageName
	"should be removed when the version  will be integrated in SmalltalkImage"
	
	^ FileDirectory baseNameFor: (FileDirectory default localNameFor: Smalltalk imageName).! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 11/13/2010 22:21'!
theScriptLoaderPackageName
	^'ScriptLoader',  CurrentMajorVersionNumber asString copyWithout: $. ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:58'!
unloadPackage: aString
	"self new unloadPackage: 'Sixx'"
	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	toRemove unload.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'stephane.ducasse 2/6/2009 17:36'!
unloadPackageNamed: aString
	"self new workingCopyFromPackageName: 'CollectionExtensions' "
	
	^ (self workingCopyFromPackageName: aString) unload
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 7/15/2006 20:39'!
unloadPackages
	"ScriptLoader new unloadPackages"
	
	| copies namesOfpackagesToUnload |
	namesOfpackagesToUnload := self packagesToUnload. 
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	(copies select: [:each | namesOfpackagesToUnload anySatisfy: [:ea | ea match: each package name ]])
		do: [:z | z unload].! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/16/2011 18:16'!
update14000! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/16/2011 18:16'!
update14001! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/17/2011 10:00'!
update14002
	"self new update14002"
	self withUpdateLog: '- remove ToolBuilder'.
	self loadTogether: self script267 merge: false.
	(MCPackage named: 'ToolBuilder-Morphic') unload.
	(MCPackage named: 'ToolBuilder-Kernel') unload.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/20/2011 10:44'!
update14003
	"self new update14003"
	self withUpdateLog: 'Issue 4425:	Finder cant find #first:
	http://code.google.com/p/pharo/issues/detail?id=4425
Issue 4427:	FlatMessageListBrowser add browse users
	http://code.google.com/p/pharo/issues/detail?id=4427'.
	self loadTogether: self script268 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/21/2011 09:35'!
update14004
	"self new update14004"
	self withUpdateLog: 'Issue 4089:	ScriptManager has the same icon as Transcript
	http://code.google.com/p/pharo/issues/detail?id=4089
Issue 4427:	FlatMessageListBrowser add browse users
	http://code.google.com/p/pharo/issues/detail?id=4427
Issue 4328:	Transcript: 5) Update problem when evaluating 1 to: ...
	http://code.google.com/p/pharo/issues/detail?id=4328'.
	self loadTogether: self script269 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/21/2011 16:15'!
update14005
	"self new update14005"
	self withUpdateLog: 'Issue 4326:	Connection timeout problem
	http://code.google.com/p/pharo/issues/detail?id=4326
Issue 4417:	Zinc does not honour network proxy configuration
	http://code.google.com/p/pharo/issues/detail?id=4417
Issue 4428:	New mechanism for Zinc servers start/stop handling after system startUp/shutDown
	http://code.google.com/p/pharo/issues/detail?id=4428'.
	self loadTogether: self script270 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/21/2011 16:56'!
update14006
	"self new update14006"
	self withUpdateLog: 'Issue 4429:	Undeclared TooklBuilder
	http://code.google.com/p/pharo/issues/detail?id=4429
Issue 4424:	Cant execute comment in Finder
	http://code.google.com/p/pharo/issues/detail?id=4424'.
	self loadTogether: self script271 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/23/2011 21:11'!
update14007
	"self new update14007"
	self withUpdateLog: 'Issue 4437:	safer FreeTypeSettings>>#monitorType
	http://code.google.com/p/pharo/issues/detail?id=4437
Issue 4434:	CrLfFileStream>>#lineEndingConvention:
	http://code.google.com/p/pharo/issues/detail?id=4434
Issue 4129:	#assert:equals: is the opposite as expected
	http://code.google.com/p/pharo/issues/detail?id=4129
'.
	self loadTogether: self script272 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/24/2011 09:53'!
update14008
	"self new update14008"
	self withUpdateLog: 'Issue 4445:	shrinkToKernel later ChangeSets cleanup
	http://code.google.com/p/pharo/issues/detail?id=4445
Issue 4436:	HandMorph mouseTrailFrom: problem
	http://code.google.com/p/pharo/issues/detail?id=4436
Issue 4443:	StrikeFontSet isSynthetic
	http://code.google.com/p/pharo/issues/detail?id=4443'.
	self loadTogether: self script273 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/24/2011 14:28'!
update14009
	"self new update14009"
	self withUpdateLog: '-  Issue 4439:	Allow cherry-picking when merging. Thanks Igor Stasenko.
	http://code.google.com/p/pharo/issues/detail?id=4439'.
	self loadTogether: self script274 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/24/2011 17:11'!
update14010
	"self new update14010"
	self withUpdateLog: '-  Issue 4439:	Allow cherry-picking when merging. Second part removing MCConflict. 
	http://code.google.com/p/pharo/issues/detail?id=4439'.
	self loadTogether: self script275 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/24/2011 17:41'!
update14011
	"self new update14011"
	self withUpdateLog: '- MC Conflict cleanup: just renaming some methods.'.
	self loadTogether: self script276 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 6/24/2011 18:26'!
update14012
	"self new update14012"
	self withUpdateLog: '- Issue 4412:	CompiledMethod >> #valueWithReceiver:arguments: instead of Object >> #withArgs:executeMethod:. 
	http://code.google.com/p/pharo/issues/detail?id=4412'.
	self loadTogether: self script277 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/26/2011 11:42'!
update14013
	"self new update14013"
	self withUpdateLog: 'Issue 3772:	taskbar doesnt adapt to resized window
	http://code.google.com/p/pharo/issues/detail?id=3772
Issue 4432:	Tweak to browser class list border
	http://code.google.com/p/pharo/issues/detail?id=4432
Issue 4450:	TimeProfileBrowser broken in Pharo OneClick 1.3, PharoCore1.3, Pharo 1.4a
	http://code.google.com/p/pharo/issues/detail?id=4450
Issue 4446:	 latestSource:location: and latestVersionOf:location:
	http://code.google.com/p/pharo/issues/detail?id=4446
Issue 4435:	initializersEnabled
	http://code.google.com/p/pharo/issues/detail?id=4435
'.
	self loadTogether: self script278 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/26/2011 17:05'!
update14014
	"self new update14014"
	self withUpdateLog: 'Issue 4351:	Eliminate SimpleButtonMorph
	http://code.google.com/p/pharo/issues/detail?id=4351
Issue 4453:	Remove References to Utilities
	http://code.google.com/p/pharo/issues/detail?id=4453
Issue 4421:	PluggableStandardWindow should be removed
	http://code.google.com/p/pharo/issues/detail?id=4421
Issue 4422:	Remove PSToolBuilder and
	http://code.google.com/p/pharo/issues/detail?id=4422'.
	self loadTogether: self script279 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/26/2011 18:30'!
update14015
	"self new update14015"
	self withUpdateLog: 'Issue 4455:	Subclasses of Obsolete classes to be removed
	http://code.google.com/p/pharo/issues/detail?id=4455
Issue 4454:	ScriptLoader: remove 1.3 update and script methods.
	http://code.google.com/p/pharo/issues/detail?id=4454
Issue 4452:	Build of 1.3 full is broken
	http://code.google.com/p/pharo/issues/detail?id=4452'.
	self loadTogether: self script280 merge: false.
	Smalltalk removeClassNamed: #PSToolBuilder.
Smalltalk removeClassNamed: #PSPluggableListSpec.
Smalltalk tools transcript initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/27/2011 12:44'!
update14016
	"empty"! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'IgorStasenko 8/12/2011 17:41'!
update14017
	"self new update14017"
	"Smalltalk  removeFromShutDownList: ImageSegment."
	self withUpdateLog: 'Issue 4458:	remove ImageSegment from ShutDownList
	http://code.google.com/p/pharo/issues/detail?id=4458
Issue 4460:	Do not try to migrate instances in ImageSegements on Disk
	http://code.google.com/p/pharo/issues/detail?id=4460
Issue 4459:	Move Polymorph FillStyles and Borders to where their superlcass lives
	http://code.google.com/p/pharo/issues/detail?id=4459'.
	self loadTogether: self script282 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/28/2011 07:51'!
update14018
	"self new update14018"
	self withUpdateLog: 'Issue 4464:	remove MaskedTextMorph
	http://code.google.com/p/pharo/issues/detail?id=4464
Issue 4462:	Move AlphaInfiniteForm to same category as InfiniteForm
	http://code.google.com/p/pharo/issues/detail?id=4462
Issue 4463:	unload deprecated 12
	http://code.google.com/p/pharo/issues/detail?id=4463'.
	self loadTogether: self script283 merge: false.
	ScriptLoader new deletePackage: 'Deprecated12'.
ScriptLoader new cleanUpForRelease.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/28/2011 09:30'!
update14019
	"self new update14019"
	self withUpdateLog: ' Issue 4391:	Support grouping windows as tab
		http://code.google.com/p/pharo/issues/detail?id=4391'.
	self loadTogether: self script284 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/28/2011 15:30'!
update14020
	"self new update14020"
	self withUpdateLog: 'Issue 4467:	Transcript does not print
	http://code.google.com/p/pharo/issues/detail?id=4467
Issue 4470:	on:fork: re-entering multiple times fix
	http://code.google.com/p/pharo/issues/detail?id=4470
Issue 4466:	Undeclared in TabLabelMorph
	http://code.google.com/p/pharo/issues/detail?id=4466'.
	self loadTogether: self script285 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 6/30/2011 08:41'!
update14021
	"self new update14021"
	self withUpdateLog: 'Issue 4474:	DNU when displaying search results in Comments
	http://code.google.com/p/pharo/issues/detail?id=4474
Issue 4473:	About HTTP proxies, settings and MacOS
	http://code.google.com/p/pharo/issues/detail?id=4473'.
	self loadTogether: self script286 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/1/2011 08:21'!
update14022
	"self new update14022"
	self withUpdateLog: 'Issue 4475:	Senders button of finder tool DNU browseSendersOf:
	http://code.google.com/p/pharo/issues/detail?id=4475
Issue 4457:	Polymorph-ToolBuilder package need to be removed
	http://code.google.com/p/pharo/issues/detail?id=4457
	(package not yet removed, just cleanup)'.
	self loadTogether: self script287 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/2/2011 12:35'!
update14023
	"self new update14023"
	self withUpdateLog: 'Issue 4457:	Polymorph-ToolBuilder package need to be removed
	http://code.google.com/p/pharo/issues/detail?id=4457
Issue 4479:	We should rename GLMUITheme into Pharo Theme
	http://code.google.com/p/pharo/issues/detail?id=4479'.
	self loadTogether: self script288 merge: false.
		ScriptLoader new deletePackage: 'Polymorph-ToolBuilder'.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/2/2011 17:00'!
update14024
	"self new update14024"
	self withUpdateLog: 'Issue 4489:	Obsolete classes in 1.4 due to Theme rename
	http://code.google.com/p/pharo/issues/detail?id=4489
Issue 4487:	Set Theme back to Pharo Theme
	http://code.google.com/p/pharo/issues/detail?id=4487		'.
	self loadTogether: self script289 merge: false.
	
ScriptLoader new cleanUpForRelease.
PharoTheme beCurrent.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/3/2011 10:15'!
update14025
	"self new update14025"
	self withUpdateLog: 'Issue 4492:	move class CornerRounder close to users
	http://code.google.com/p/pharo/issues/detail?id=4492
Issue 4494:	remove PNMReadWriter
	http://code.google.com/p/pharo/issues/detail?id=4494
Issue 4490:	Deprecated12 code is still there
	http://code.google.com/p/pharo/issues/detail?id=4490'.
	self loadTogether: self script290 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/5/2011 12:59'!
update14026
	"self new update14026"
	ScriptLoader new deletePackage: 'Graphics-Support'.
ScriptLoader new deletePackage: 'System-SourceAndChangeFile'.
	self withUpdateLog: 'Issue 4496:	Package Graphics-Support is empty
	http://code.google.com/p/pharo/issues/detail?id=4496
Issue 4497:	package System-SourceAndChangeFile is empty
	http://code.google.com/p/pharo/issues/detail?id=4497'.
	self loadTogether: self script291 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/6/2011 09:26'!
update14027
	"self new update14027"
	self withUpdateLog: 'Issue 4502:	Fix for TimeProfileBrowser
	http://code.google.com/p/pharo/issues/detail?id=4502
'.
	self loadTogether: self script292 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/7/2011 17:03'!
update14028
	"self new update14028"
	self withUpdateLog: 'Issue 4503:	Suggested fix using directly the Display canvas, and some low-level drawing
	http://code.google.com/p/pharo/issues/detail?id=4503'.
	self loadTogether: self script293 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/8/2011 12:19'!
update14029
	"self new update14029"
	self withUpdateLog: ' Issue 4506:	Revert to old Transcript
	http://code.google.com/p/pharo/issues/detail?id=4506'.
	self loadTogether: self script294 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/8/2011 12:50'!
update14030
	"self new update14030"
	self withUpdateLog: ' Issue 4506:	Revert to old Transcript. Two
	http://code.google.com/p/pharo/issues/detail?id=4506'.
	self loadTogether: self script295 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/8/2011 13:22'!
update14031
	"self new update14031"
	self withUpdateLog: ' Issue 4506:	Revert to old Transcript. Three
	http://code.google.com/p/pharo/issues/detail?id=4506'.
	self loadTogether: self script296 merge: false.
	ThreadSafeTranscript install.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/8/2011 14:21'!
update14032
	"self new update14032"
	self withUpdateLog: '- Issue 4411:	examples in Number comments. Thanks Nicolas Cellier and Camillo Bruni.
	http://code.google.com/p/pharo/issues/detail?id=4411
	
- Issue 4414:	test for Number. Thanks Nicolas Cellier and Camillo Bruni.
	http://code.google.com/p/pharo/issues/detail?id=4414'.
	self loadTogether: self script297 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/8/2011 16:17'!
update14033
	"self new update14033"
	self addHomeRepositoryToAllPackages.
	self withUpdateLog: '- Adding Ring (after merging three packages). Thanks Veronica Uquillas Gomez'.
	self loadTogether: self script298 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/8/2011 17:04'!
update14034
	"self new update14034"
	self withUpdateLog: '- Issue 4469:	Clean up old HTTP Code. Thanks Sven. '.
	self loadTogether: self script299 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/14/2011 12:21'!
update14035
	"self new update14035"
	self withUpdateLog: '- Issue 4520:	Zinc update
	http://code.google.com/p/pharo/issues/detail?id=4520
	
ZnDefaultServerDelegate>>#echoRequest: added option to delay the response to /echo with a specified number of seconds, as in echo?delay=60

added ZnSingleThreadedServer>>#onRequestRespond: convenience method

implemented client side support for If-Modified-Since and Not Modified:
- added ZnRequest>>#setIfModifiedSince:
- refactored ZnMessage>>#readFrom to call #readEntityFrom:
- overwritten ZnResponse>>#readEntityFrom: to take special no content response into account
- extended ZnUtils class>>#httpDate: to accept any argument that understands #asTimeStamp
'.
	self loadTogether: self script300 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/14/2011 16:28'!
update14036
	"self new update14036"
	self withUpdateLog: '- Issue 4519:	-1 copySignTo: 0.0 should return Float negativeZero. Thanks Nicolas Cellier.
	http://code.google.com/p/pharo/issues/detail?id=4519	
- Issue 4518:	Don t inline digitValue	
Thanks Nicolas Cellier.
	http://code.google.com/p/pharo/issues/detail?id=4518'.
	self loadTogether: self script301 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/14/2011 17:15'!
update14037
	"self new update14037"
	self withUpdateLog: '- Issue 4522:	Separate ceiling/floor/truncated/rounded tests for Float and Fraction. Thanks Nicolas Cellier
	http://code.google.com/p/pharo/issues/detail?id=4522
	
- Issue 4517:	Better estimation of number of digits in base 10
	Thanks Nicolas Cellier
	http://code.google.com/p/pharo/issues/detail?id=4517
	
- Issue 4516:	copying a class should copy the sharedPools
	Thanks Nicolas Cellier
	http://code.google.com/p/pharo/issues/detail?id=4516'.
	self loadTogether: self script302 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/14/2011 20:16'!
update14038
	"self new update14038"
	self withUpdateLog: '- Issue 4413:	Better error message for MC. Thanks Camillo Bruni and FBS.

- Issue 4507:	MC Commit. Thanks Camillo Bruni.'.
	self loadTogether: self script303 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/14/2011 21:31'!
update14039
	"self new update14039"
	self withUpdateLog: '-  Issue 3916: Cannot input some Russian characters at text editors. Thanks guys

- Issue 4523: SetElement comment is missing. Thanks Nicolas Cellier'.
	self loadTogether: self script304 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/15/2011 22:31'!
update14040
	"self new update14040"
	self withUpdateLog: '- Issue 4504: check button not updated. Thanks Camillo Bruni.
	http://code.google.com/p/pharo/issues/detail?id=4504
	
- Issue 4525: Fraction asFloat does not return negativeZero in case of Underflow. Thanks Nicolas Cellier.
	http://code.google.com/p/pharo/issues/detail?id=4525
	
- Issue 4524:	DomainError signalTo: sets wrong bounds
	Thanks Nicolas Cellier.
	http://code.google.com/p/pharo/issues/detail?id=4524'.
	self loadTogether: self script305 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/15/2011 22:51'!
update14041
	"self new update14041"
	self withUpdateLog: '- Issue 4480:	Cleaning Direct Compiler Reference.
	Thanks Jean-Baptiste Arnaud'.
	self loadTogether: self script306 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/16/2011 22:19'!
update14042
	"self new update14042"
	self withUpdateLog: '- Interval>>rangeIncludes: is mis-categorized. Thanks Sean Denigris

- Issue 4505:	ExternalSemaphore class>>#safelyRegisterExternalObject: silently fails when running out of VM space. Thanks Henrik Sperre Johansen
	http://code.google.com/p/pharo/issues/detail?id=4505'.
	self loadTogether: self script307 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/16/2011 23:02'!
update14043
	"self new update14043"
	self addHomeRepositoryToAllPackages.
	self withUpdateLog: '- Adding ring container objects and fixing missing isRingObject.
	all tests green except one.'.
	self loadTogether: self script308 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2011 15:27'!
update14044
	"self new update14044"
	self withUpdateLog: '- Issue 4530:	Source enh. Thanks Veronica Uquillas-Gomez.
	
- Issue 4529:	Announcement delivery breaks if last subscriber is curtailed. Thanks Henrik Johanssen.'.
	self loadTogether: self script309 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2011 16:00'!
update14045
	"self new update14045"
	self withUpdateLog: 'cleaning ring packages'.
	self loadTogether: self script310 merge: false.
	self deletePackage: 'Ring-Tests-Core-Containers'.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2011 16:34'!
update14046
	"self new update14046"
	self addHomeRepositoryToAllPackages.
	self withUpdateLog: 'adding Ring-Tests-Containers'.
	self loadTogether: self script311 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2011 17:04'!
update14047
	"self new update14047"
	self withUpdateLog: '- Issue 4527:	serialPort enh.
	Thanks Bill Schwab.

- Fixing getPreamble: '.
	self loadTogether: self script312 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/18/2011 17:48'!
update14048
	"self new update14048"
	self withUpdateLog: '- Issue 4528: Exception on:fork: enhancement. Thanks Igor Stasenko and Lukas Renggli for the idea and ... '.
	self loadTogether: self script313 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/19/2011 10:46'!
update14049
	"self new update14049"
	self withUpdateLog: 'Merging latest ring core fixes + tests with veronica.'.
	self loadTogether: self script314 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/19/2011 13:42'!
update14050
	"self new update14050"
	self withUpdateLog: 'Preparation for Ring integration'.
	self loadTogether: self script315 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/22/2011 15:33'!
update14051
	"self new update14051"
	self withUpdateLog: '- Issue 4544:	Better vmVersion identification. Since now vm has attribute number 1009 we can trace back to the version control  system. Thanks Igor Stasenko and Eliot Miranda.
- Ring enhancements. Thanks Veronica Uquillas-Gomez'.
	self loadTogether: self script316 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/22/2011 15:53'!
update14052
	"self new update14052"
	self withUpdateLog: '-  Issue 4537:	Removing Canvas>>shadowColor & friends cleanup. Thanks Igor Stasenko.'.
	self loadTogether: self script317 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/22/2011 16:17'!
update14053
	"self new update14053"
	self withUpdateLog: '-  Issue 4540:	Removing NullEncoder/FlattenEncoder. Thanks Igor Stasenko.
	
- Issue 4538:	(Array & CompiledMethod)>>hasLiteral: bug. literalEqual for VariableBinding shall use identity. We  make sure that a binding is considered equal when it is identical to another because a binding can have the same key and value but refers to another binding and as such not be equal. Thanks Nicolas Cellier.
	hasLiteral and refersToLiteral now ses literalEqual. Thanks Nicolas Cellier.'.
	self loadTogether: self script318 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/22/2011 16:34'!
update14054
	"self new update14054"
	self withUpdateLog: '-  Issue 4534:	leftShiftDown is obsolete.
	http://code.google.com/p/pharo/issues/detail?id=4534'.
	self loadTogether: self script319 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/22/2011 18:16'!
update14055
	"self new update14055"
	self withUpdateLog: '-  Issue 4535: automatically expand the context stack in the debugger when the last item is selected. Thanks Camillo Bruni..
	http://code.google.com/p/pharo/issues/detail?id=4535
	
- Issue 4541: UUIDs not so unique.  Thanks Torsten Bergmann
	http://code.google.com/p/pharo/issues/detail?id=4541
	
- Issue 4536: Filter out "kernel" message sends in the debugger. 
	http://code.google.com/p/pharo/issues/detail?id=4536'.
	self loadTogether: self script320 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/22/2011 18:39'!
update14056
	"self new update14056"
	self withUpdateLog: '- Issue 4513:	ScrollBar and MorphicModel needs cleaning. Stef and Igor killing tha big monster - Part one. :) 
	http://code.google.com/p/pharo/issues/detail?id=4513'.
	self loadTogether: self script321 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'IgorStasenko 7/22/2011 19:25'!
update14057
	"self new update14057"
	self withUpdateLog: '- Issue 4513:	ScrollBar and MorphicModel needs cleaning. Stef and Igor killing tha big monster - Part two. :) 
	http://code.google.com/p/pharo/issues/detail?id=4513
	
Gary it would be good that you check because we have two ways to to a perform: accessor and setValueSelector while only one would be enough. '.
	self loadTogether: self script322 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/22/2011 22:32'!
update14058
	"self new update14058"
	self withUpdateLog: ' Issue 4546:	Time Profiler copy. Thanks Alain Plantec and Hilaire Fernandez.'.
	self loadTogether: self script323 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/22/2011 23:16'!
update14059
	"self new update14059"
	self withUpdateLog: '- Issue 4546:	Time Profiler copy. Second fix.
		http://code.google.com/p/pharo/issues/detail?id=4546
- Issue 4543:	Wrong calculated size of objects in memory.
		http://code.google.com/p/pharo/issues/detail?id=4543'.
	self loadTogether: self script324 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/26/2011 15:34'!
update14060
	"self new update14060"
	self withUpdateLog: '- enhancing Ring and fixing some API for better tools integration. SystemNavigation is now using Ring objects.
todo: should fix some tests on unsentMessages'.
	self loadTogether: self script325 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'IgorStasenko 7/27/2011 10:36'!
update14061
	"self new update14061"
	self withUpdateLog: '- Issue 4555: 	Fix SUnit to prevent forked process from escaping to debugger'.
	self loadTogether: self script326 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/28/2011 13:23'!
update14062
	"self new update14062"
	self withUpdateLog: 'Issue 4500:	Put SUnit-Help be put into a separate package
Issue 4558:	Test Runner UI is strange'.
	self loadTogether: self script327 merge: false.
	(MCPackage named: 'SUnit') workingCopy unregister.
ScriptLoader new addHomeRepositoryToAllPackages.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 7/28/2011 14:49'!
update14063
	"self new update14063"
	self withUpdateLog: 'Issue 4533:	Transcript patch for the Kernel image
	http://code.google.com/p/pharo/issues/detail?id=4533
Issue 4554:	MorphicUIManager does not implement #confirm:label:
	http://code.google.com/p/pharo/issues/detail?id=4554'.
	self loadTogether: self script328 merge: false.
	ScriptLoader new cleanUpForRelease.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/28/2011 23:15'!
update14064
	"self new update14064"
	self withUpdateLog: 'Issue 4564:	Scrollbar and slider changes broke Combox.'.
	self loadTogether: self script329 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/28/2011 23:50'!
update14065
	"self new update14065"
	self withUpdateLog: 'DeleteSunit package since it is overlapping with the other now.'.
	self loadTogether: self script330 merge: false.
	self deletePackage: 'SUnit'.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 7/29/2011 15:50'!
update14066
	"self new update14066"
	self withUpdateLog: '- reverting old method newUpdates for now.'.
	self loadTogether: self script331 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/1/2011 11:06'!
update14067
	"self new update14067"
	self withUpdateLog: 'Issue 4566:	SUnit: Fix for tagging expectedFailure using pragmas
	http://code.google.com/p/pharo/issues/detail?id=4566
Issue 4570:	adding bitString to SmallInteger
	http://code.google.com/p/pharo/issues/detail?id=4570
Issue 4561:	Monticello GUI is broken
	http://code.google.com/p/pharo/issues/detail?id=4561'.
	self loadTogether: self script332 merge: false.
	ScriptLoader new addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/1/2011 11:42'!
update14068
	"self new update14068"
	self withUpdateLog: 'Issue 4563:	should not we remove deprecated 1.2 ?	
	http://code.google.com/p/pharo/issues/detail?id=4563'.
	self loadTogether: self script333 merge: false.
	(MCPackage named: 'Deprecated12') unload.
ScriptLoader new cleanUpForRelease.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/1/2011 22:59'!
update14069
	"self new update14069"
	self withUpdateLog: '- fixed CommentReference missing backward compatibility methods. 

- fixed some methodSymbol references 
	http://code.google.com/p/pharo/issues/detail?id=4550
	
- fixed eval and execution of code in FlatMessageListBrowser

Issue 4580:	RGMethodDefinition protocol can be nil
	- fix results of protocolAt: and timeStampAt: of SourceFileArray.
	- add test to cover SourceFileArray utils methods
	http://code.google.com/p/pharo/issues/detail?id=4580
'.
	self loadTogether: self script334 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/2/2011 10:39'!
update14070
	"self new update14070"
	self withUpdateLog: 'Issue 3923:	#condenseChanges not working in 1.3
	http://code.google.com/p/pharo/issues/detail?id=3923'.
	self loadTogether: self script335 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/2/2011 19:38'!
update14071
	"self new update14071"
	self withUpdateLog: 'Issue 4582:	Failing tests: CompiledMethodTest restReadField and testWriteField
	http://code.google.com/p/pharo/issues/detail?id=4582
Issue 4583:	Undeclared in #allLocalCallsOn:ofClass:
	http://code.google.com/p/pharo/issues/detail?id=4583
Issue 4585:	Failing Test: uncategorized methods in MethodReference
	http://code.google.com/p/pharo/issues/detail?id=4585
Issue 4584:	Undeclared in #doTestDebuggerTempAccessWith:with:
	http://code.google.com/p/pharo/issues/detail?id=4584
Issue 4588:	Failing test: #testSizeInMemoryNormalClasses
	http://code.google.com/p/pharo/issues/detail?id=4588
Issue 4590:	Polymorph improvements
	http://code.google.com/p/pharo/issues/detail?id=4590'.
	self loadTogether: self script336 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/2/2011 22:58'!
update14072
	"self new update14072"
	self withUpdateLog: '- Issue 3433:	Color improvement
	http://code.google.com/p/pharo/issues/detail?id=3433

- Better class comment for FlatListMessageBrowser'.
	self loadTogether: self script337 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/3/2011 10:21'!
update14073
	"self new update14073"
	self withUpdateLog: 'Issue 4574:	ChangedMessageSet is not referenced
	http://code.google.com/p/pharo/issues/detail?id=4574
Issue 4569:	load updates just loads the last update?
	http://code.google.com/p/pharo/issues/detail?id=4569'.
	self loadTogether: self script338 merge: false.
		ScriptLoader new addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/4/2011 08:41'!
update14074
	"self new update14074"
	self withUpdateLog: 'Issue 4565:	Monticello workflow broken
	http://code.google.com/p/pharo/issues/detail?id=4565
Issue 4597:	StrikeFont aggressive cleanup should remove DejaVu source
	http://code.google.com/p/pharo/issues/detail?id=4597
'.
	self loadTogether: self script339 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/4/2011 12:30'!
update14075
	"self new update14075"
	self withUpdateLog: 'Issue 4596:	WeakOrderedColllection array is replaced by an Array instead of a WeakArray
	(part 1)	'.
	self loadTogether: self script340 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/4/2011 12:34'!
update14076
	"self new update14076"
	self withUpdateLog: 'Issue 4596:	WeakOrderedColllection array is replaced by an Array instead of a WeakArray
	(part 2)	'.
	self loadTogether: self script341 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/4/2011 15:34'!
update14077
	"self new update14077"
	self withUpdateLog: '- Issue 4598:	Improve MCBrowser search. Thanks Camillo.
	http://code.google.com/p/pharo/issues/detail?id=4598
- Issue 4600:	Add Search Morph	
	http://code.google.com/p/pharo/issues/detail?id=4600. Thanks Camillo.
- Issue 4533:	Transcript patch for the Kernel image
	http://code.google.com/p/pharo/issues/detail?id=4533. Thanks Pavel Krivanek'.
	self loadTogether: self script342 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'IgorStasenko 8/8/2011 15:02'!
update14078
	"self new update14078"
	self withUpdateLog: '- add ensureCr for vmmaker compatibility to Transcript'.
	self loadTogether: self script343 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/9/2011 18:11'!
update14079
	"self new update14079"
	self withUpdateLog: '-  Issue 4550:	methodSymbol is a bad name for selector.
	Couple more fixes'.
	self loadTogether: self script344 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/10/2011 23:35'!
update14080
	"self new update14080"
	self withUpdateLog: '-  Issue 4607:	Refactor Debugger >> content:notifying:. Thanks Camillo Bruni.
	http://code.google.com/p/pharo/issues/detail?id=4607
	
- Issue 4606: Fix drawing shadow of morphs. Thanks Igor Stasenko.
	http://code.google.com/p/pharo/issues/detail?id=4606
	
-  Issue 4607:	Minor-fix-to-the-old-MCMergeBrowser. Thanks Camillo Bruni.
	http://code.google.com/p/pharo/issues/detail?id=4601
	
'.
	self loadTogether: self script345 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 8/12/2011 12:01'!
update14081
	"self new update14081"
	self withUpdateLog: '- Issue 4614:	Ring latest changes - firt shot at = for entities and a lot more . Thanks Veronica Uquillas Gomez
	http://code.google.com/p/pharo/issues/detail?id=4614'.
	self loadTogether: self script346 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/12/2011 14:23'!
update14082
	"self new update14082"
	self withUpdateLog: '- Load FS

'.
	self loadTogether: self script347 merge: false.
	ScriptLoader new addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/12/2011 15:05'!
update14083
	"self new update14083"
	ScriptLoader new addHomeRepositoryToAllPackages.
	self withUpdateLog: '- Load Collections-Aritmetic
- Issue 4577:	RecentMessageSet is not referenced anymore
	http://code.google.com/p/pharo/issues/detail?id=4577

'.
	self loadTogether: self script348 merge: false.
	addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/12/2011 15:31'!
update14084
	"self new update14084"
	self withUpdateLog: 'Issue 4619:	Fixing SystemNavigationTest
	http://code.google.com/p/pharo/issues/detail?id=4619'.
	self loadTogether: self script349 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/12/2011 16:20'!
update14085
	"self new update14085"
	self withUpdateLog: 'Issue 4587:	Failing tests related to renaming classes
	http://code.google.com/p/pharo/issues/detail?id=4587'.
	self loadTogether: self script350 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/12/2011 16:50'!
update14086
	"self new update14086"
	self withUpdateLog: 'Issue 4621:	ToolRegistery bug
	http://code.google.com/p/pharo/issues/detail?id=4621
Issue 4610:	MCWorkingCopyBrowser references lot of undefined variables
	http://code.google.com/p/pharo/issues/detail?id=4610'.
	self loadTogether: self script351 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/12/2011 17:26'!
update14087
	"self new update14087"
	self withUpdateLog: 'Shout
'.
	self loadTogether: self script352 merge: false.
	ScriptLoader new addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/12/2011 18:25'!
update14088
	"self new update14088"
	self withUpdateLog: 'Issue 4625:	Fix execution of code in Implementor/sender
	http://code.google.com/p/pharo/issues/detail?id=4625
Issue 4628:	Nuking ImageSegment (Part I)
	http://code.google.com/p/pharo/issues/detail?id=4628'.
	self loadTogether: self script353 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 8/12/2011 18:38'!
update14089
	"self new update14089"
	self withUpdateLog: '- FS update'.
	self loadTogether: self script354 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 1/31/2011 22:22'!
updateUpdatesList: aString
	"ScriptLoader new updateUpdatesList: 'cleanUpMethods'"
	
	| str |
	str := FileDirectory default oldFileNamed: self updatesListFileName.
	[	str
			setToEnd;
			cr;
			nextPutAll: self currentUpdateVersionNumber asString;
			nextPutAll: '-Pha-', aString, '.cs' ]
		ensure: [ str close ]! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 2/10/2011 15:40'!
updatesListFileName

	^ 'updates', (SystemVersion current majorMinor:''), '.list'! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'lr 3/14/2010 21:13'!
verifyNewUpdate
	self repository: self class defaultMCWaitingFolder.
	self class loadLatestPackage: 'ScriptLoader' fromRepository: self repository.
	self perform: ('update' , self getLatestUpdateNumber asString) asSymbol.
	(self confirm: 'Completed loading the new update. Run all test now?')
		ifTrue: [ 
			Author fullName: 'tester'.
			Smalltalk globals at: #TestRunner ifPresent: [ :class | class open model runAll ] ]! !

!ScriptLoader methodsFor: 'private' stamp: 'al 11/1/2008 18:19'!
waitingFolderMCZFiles
	^ self class defaultMCWaitingFolder allFileNames
		reject: [:each | each =  '.DS_Store']! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/24/2008 16:45'!
withUpdateLog: aString

	self logStream nextPutAll: ' ------------------------------------------------------' ; cr.
	self logStream nextPutAll: thisContext sender selector asString. 
	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'sd 3/24/2008 17:31'!
workingCopyFromPackageName: aString
	"self new workingCopyFromPackageName: '39Deprecated' "
	
	|pa|
	pa := MCPackage named: aString.
	^ pa workingCopy 
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'sd 7/8/2006 18:20'!
writeCS: extensionAndNumber forUpdate: updateNumber
	"ScriptLoader new writeCS: '-sd.210' forUpdate: 7037"
	
	self writeCS: extensionAndNumber forUpdate: updateNumber withName: 'changeMe'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 2/25/2010 18:09'!
writeCS: extensionAndNumber forUpdate: updateNumber withName: aSt
	"ScriptLoader new writeCS: '-md.2929' forUpdate: 7049 withName: 'cleanUpMethods'"
	

	FileDirectory default 
		forceNewFileNamed:  updateNumber asString, 'update', aSt, '.cs'
		do: [ :stream | self generateCS: extensionAndNumber fromUpdate: updateNumber on: stream].
! !
ScriptLoader initialize!
